/**
    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
      http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.pepstock.charba.client.colors;

/**
 * Google Chart colors provided as enumeration of colors.
 * 
 * @author Andrea "Stock" Stocchero
 * 
 * @see <a href= "https://stackoverflow.com/questions/32131668/from-where-can-i-get-list-of-all-color-patterns-used-by-google-charts">Google Chart Color on Stackoverflow</a>
 *
 */
public enum GoogleChartColor implements IsEnumeratedColor
{
	/**
	 * Google chart color name "COLOR_00" - <span style="background-color:#3366cc; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_00("#3366cc"),

	/**
	 * Google chart color name "COLOR_01" - <span style="background-color:#dc3912; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_01("#dc3912"),

	/**
	 * Google chart color name "COLOR_02" - <span style="background-color:#ff9900; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_02("#ff9900"),

	/**
	 * Google chart color name "COLOR_03" - <span style="background-color:#109618; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_03("#109618"),

	/**
	 * Google chart color name "COLOR_04" - <span style="background-color:#990099; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_04("#990099"),

	/**
	 * Google chart color name "COLOR_05" - <span style="background-color:#0099c6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_05("#0099c6"),

	/**
	 * Google chart color name "COLOR_06" - <span style="background-color:#dd4477; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_06("#dd4477"),

	/**
	 * Google chart color name "COLOR_07" - <span style="background-color:#66aa00; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_07("#66aa00"),

	/**
	 * Google chart color name "COLOR_08" - <span style="background-color:#b82e2e; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_08("#b82e2e"),

	/**
	 * Google chart color name "COLOR_09" - <span style="background-color:#316395; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_09("#316395"),

	/**
	 * Google chart color name "COLOR_10" - <span style="background-color:#994499; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_10("#994499"),

	/**
	 * Google chart color name "COLOR_11" - <span style="background-color:#22aa99; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_11("#22aa99"),

	/**
	 * Google chart color name "COLOR_12" - <span style="background-color:#aaaa11; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_12("#aaaa11"),

	/**
	 * Google chart color name "COLOR_13" - <span style="background-color:#6633cc; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_13("#6633cc"),

	/**
	 * Google chart color name "COLOR_14" - <span style="background-color:#e67300; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_14("#e67300"),

	/**
	 * Google chart color name "COLOR_15" - <span style="background-color:#8b0707; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_15("#8b0707"),

	/**
	 * Google chart color name "COLOR_16" - <span style="background-color:#651067; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_16("#651067"),

	/**
	 * Google chart color name "COLOR_17" - <span style="background-color:#329262; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_17("#329262"),

	/**
	 * Google chart color name "COLOR_18" - <span style="background-color:#5574a6; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_18("#5574a6"),

	/**
	 * Google chart color name "COLOR_19" - <span style="background-color:#3b3eac; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_19("#3b3eac"),

	/**
	 * Google chart color name "COLOR_20" - <span style="background-color:#b77322; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_20("#b77322"),

	/**
	 * Google chart color name "COLOR_21" - <span style="background-color:#16d620; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_21("#16d620"),

	/**
	 * Google chart color name "COLOR_22" - <span style="background-color:#b91383; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_22("#b91383"),

	/**
	 * Google chart color name "COLOR_23" - <span style="background-color:#f4359e; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_23("#f4359e"),

	/**
	 * Google chart color name "COLOR_24" - <span style="background-color:#9c5935; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_24("#9c5935"),

	/**
	 * Google chart color name "COLOR_25" - <span style="background-color:#a9c413; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_25("#a9c413"),

	/**
	 * Google chart color name "COLOR_26" - <span style="background-color:#2a778d; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_26("#2a778d"),

	/**
	 * Google chart color name "COLOR_27" - <span style="background-color:#668d1c; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_27("#668d1c"),

	/**
	 * Google chart color name "COLOR_28" - <span style="background-color:#bea413; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_28("#bea413"),

	/**
	 * Google chart color name "COLOR_29" - <span style="background-color:#0c5922; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_29("#0c5922"),

	/**
	 * Google chart color name "COLOR_30" - <span style="background-color:#743411; border-style: solid; border-width: 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLOR_30("#743411");

	// color instance
	private final IsColor color;

	/**
	 * Creates a color with HEX value.
	 * 
	 * @param hexValue color string representation in hex mode
	 */
	private GoogleChartColor(String hexValue) {
		color = ColorBuilder.buildByHexValue(hexValue, false);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.colors.IsEnumeratedColor#getColor()
	 */
	@Override
	public IsColor getColor() {
		return color;
	}

}