/**
    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
      http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.pepstock.charba.client.events;

import java.util.List;

import org.pepstock.charba.client.enums.ChartEventProperty;
import org.pepstock.charba.client.items.DatasetReference;

/**
 * Event which is fired when the user clicks on the chart.
 * 
 * @author Andrea "Stock" Stocchero
 */
public final class ChartClickEvent extends AbstractChartTypedEvent {

	/**
	 * Event type
	 */
	public static final EventType TYPE = EventType.create(ChartClickEvent.class);

	/**
	 * Creates the event with a list of items with dataset references related to the click
	 * 
	 * @param eventContext event context generated by CHART.js
	 * @param items a list of items with dataset references related to the click
	 */
	public ChartClickEvent(ChartEventContext eventContext, List<DatasetReference> items) {
		super(eventContext, TYPE, ChartEventProperty.ON_CLICK, items);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.events.Event#dispatch(org.pepstock.charba.client.events.EventHandler)
	 */
	@Override
	protected void dispatch(EventHandler handler) {
		// checks if handler is a correct instance
		if (handler instanceof ChartClickEventHandler) {
			// casts handler
			ChartClickEventHandler myHandler = (ChartClickEventHandler) handler;
			// invokes
			myHandler.onClick(this);
		}
	}

}