/**
    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
      http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.pepstock.charba.client.intl;

/**
 * Enumerates the language identifiers which can be used to create and manage locale.
 * 
 * @author Andrea "Stock" Stocchero
 */
public enum Language implements IsLocaleItem
{
	/**
	 * International key, to use for localization, for <b>Afar</b> language.
	 */
	AFAR("aar", "aa", "Afar"),

	/**
	 * International key, to use for localization, for <b>Afrikaans</b> language.
	 */
	AFRIKAANS("afr", "af", "Afrikaans"),

	/**
	 * International key, to use for localization, for <b>Aghem</b> language.
	 */
	AGHEM("agq", "Aghem"),

	/**
	 * International key, to use for localization, for <b>Akan</b> language.
	 */
	AKAN("aka", "ak", "Akan"),

	/**
	 * International key, to use for localization, for <b>Albanian</b> language.
	 */
	ALBANIAN("sqi", "sq", "Albanian"),

	/**
	 * International key, to use for localization, for <b>Amharic</b> language.
	 */
	AMHARIC("amh", "am", "Amharic"),

	/**
	 * International key, to use for localization, for <b>Arabic</b> language.
	 */
	ARABIC("ara", "ar", "Arabic"),

	/**
	 * International key, to use for localization, for <b>Armenian</b> language.
	 */
	ARMENIAN("hye", "hy", "Armenian"),

	/**
	 * International key, to use for localization, for <b>Assamese</b> language.
	 */
	ASSAMESE("asm", "as", "Assamese"),

	/**
	 * International key, to use for localization, for <b>Asturian</b> language.
	 */
	ASTURIAN("ast", "Asturian"),

	/**
	 * International key, to use for localization, for <b>Asu (Tanzania)</b> language.
	 */
	ASU("asa", "Asu (Tanzania)"),

	/**
	 * International key, to use for localization, for <b>Azerbaijani</b> language.
	 */
	AZERBAIJANI("aze", "az", "Azerbaijani"),

	/**
	 * International key, to use for localization, for <b>Bafia</b> language.
	 */
	BAFIA("ksf", "Bafia"),

	/**
	 * International key, to use for localization, for <b>Bambara</b> language.
	 */
	BAMBARA("bam", "bm", "Bambara"),

	/**
	 * International key, to use for localization, for <b>Basa (Cameroon)</b> language.
	 */
	BASA("bas", "Basa (Cameroon)"),

	/**
	 * International key, to use for localization, for <b>Bashkir</b> language.
	 */
	BASHKIR("bak", "ba", "Bashkir"),

	/**
	 * International key, to use for localization, for <b>Basque</b> language.
	 */
	BASQUE("eus", "eu", "Basque"),

	/**
	 * International key, to use for localization, for <b>Belarusian</b> language.
	 */
	BELARUSIAN("bel", "be", "Belarusian"),

	/**
	 * International key, to use for localization, for <b>Bemba (Zambia)</b> language.
	 */
	BEMBA("bem", "Bemba (Zambia)"),

	/**
	 * International key, to use for localization, for <b>Bena (Tanzania)</b> language.
	 */
	BENA("bez", "Bena (Tanzania)"),

	/**
	 * International key, to use for localization, for <b>Bengali</b> language.
	 */
	BENGALI("ben", "bn", "Bengali"),

	/**
	 * International key, to use for localization, for <b>Bilin</b> language.
	 */
	BILIN("byn", "Bilin"),

	/**
	 * International key, to use for localization, for <b>Bodo (India)</b> language.
	 */
	BODO("brx", "Bodo (India)"),

	/**
	 * International key, to use for localization, for <b>Bosnian</b> language.
	 */
	BOSNIAN("bos", "bs", "Bosnian"),

	/**
	 * International key, to use for localization, for <b>Breton</b> language.
	 */
	BRETON("bre", "br", "Breton"),

	/**
	 * International key, to use for localization, for <b>Bukusu</b> language.
	 */
	BUKUSU("bxk", "Bukusu"),

	/**
	 * International key, to use for localization, for <b>Bulgarian</b> language.
	 */
	BULGARIAN("bul", "bg", "Bulgarian"),

	/**
	 * International key, to use for localization, for <b>Burmese</b> language.
	 */
	BURMESE("mya", "my", "Burmese"),

	/**
	 * International key, to use for localization, for <b>Catalan</b> language.
	 */
	CATALAN("cat", "ca", "Catalan"),

	/**
	 * International key, to use for localization, for <b>Cebuano</b> language.
	 */
	CEBUANO("ceb", "Cebuano"),

	/**
	 * International key, to use for localization, for <b>Central Atlas Tamazight</b> language.
	 */
	CENTRAL_ATLAS_TAMAZIGHT("tzm", "Central Atlas Tamazight"),

	/**
	 * International key, to use for localization, for <b>Central Kurdish</b> language.
	 */
	CENTRAL_KURDISH("ckb", "Central Kurdish"),

	/**
	 * International key, to use for localization, for <b>Chakma</b> language.
	 */
	CHAKMA("ccp", "Chakma"),

	/**
	 * International key, to use for localization, for <b>Chechen</b> language.
	 */
	CHECHEN("che", "ce", "Chechen"),

	/**
	 * International key, to use for localization, for <b>Cherokee</b> language.
	 */
	CHEROKEE("chr", "Cherokee"),

	/**
	 * International key, to use for localization, for <b>Chiga</b> language.
	 */
	CHIGA("cgg", "Chiga"),

	/**
	 * International key, to use for localization, for <b>Chinese</b> language.
	 */
	CHINESE("zho", "zh", "Chinese"),

	/**
	 * International key, to use for localization, for <b>Church Slavic</b> language.
	 */
	CHURCH_SLAVIC("chu", "cu", "Church Slavic"),

	/**
	 * International key, to use for localization, for <b>Congo Swahili</b> language.
	 */
	CONGO_SWAHILI("swc", "Congo Swahili"),

	/**
	 * International key, to use for localization, for <b>Cornish</b> language.
	 */
	CORNISH("cor", "kw", "Cornish"),

	/**
	 * International key, to use for localization, for <b>Corsican</b> language.
	 */
	CORSICAN("cos", "co", "Corsican"),

	/**
	 * International key, to use for localization, for <b>Croatian</b> language.
	 */
	CROATIAN("hrv", "hr", "Croatian"),

	/**
	 * International key, to use for localization, for <b>Cusco Quechua</b> language.
	 */
	CUSCO_QUECHUA("quz", "Cusco Quechua"),

	/**
	 * International key, to use for localization, for <b>Czech</b> language.
	 */
	CZECH("ces", "cs", "Czech"),

	/**
	 * International key, to use for localization, for <b>Danish</b> language.
	 */
	DANISH("dan", "da", "Danish"),

	/**
	 * International key, to use for localization, for <b>Dari</b> language.
	 */
	DARI("prs", "Dari"),

	/**
	 * International key, to use for localization, for <b>Dhivehi</b> language.
	 */
	DHIVEHI("div", "dv", "Dhivehi"),

	/**
	 * International key, to use for localization, for <b>Duala</b> language.
	 */
	DUALA("dua", "Duala"),

	/**
	 * International key, to use for localization, for <b>Dutch</b> language.
	 */
	DUTCH("nld", "nl", "Dutch"),

	/**
	 * International key, to use for localization, for <b>Dzongkha</b> language.
	 */
	DZONGKHA("dzo", "dz", "Dzongkha"),

	/**
	 * International key, to use for localization, for <b>Eastern Yiddish</b> language.
	 */
	EASTERN_YIDDISH("ydd", "Eastern Yiddish"),

	/**
	 * International key, to use for localization, for <b>Embu</b> language.
	 */
	EMBU("ebu", "Embu"),

	/**
	 * International key, to use for localization, for <b>English</b> language.
	 */
	ENGLISH("eng", "en", "English"),

	/**
	 * International key, to use for localization, for <b>Esperanto</b> language.
	 */
	ESPERANTO("epo", "eo", "Esperanto"),

	/**
	 * International key, to use for localization, for <b>Estonian</b> language.
	 */
	ESTONIAN("est", "et", "Estonian"),

	/**
	 * International key, to use for localization, for <b>Ewe</b> language.
	 */
	EWE("ewe", "ee", "Ewe"),

	/**
	 * International key, to use for localization, for <b>Ewondo</b> language.
	 */
	EWONDO("ewo", "Ewondo"),

	/**
	 * International key, to use for localization, for <b>Fanti</b> language.
	 */
	FANTI("fat", "Fanti"),

	/**
	 * International key, to use for localization, for <b>Faroese</b> language.
	 */
	FAROESE("fao", "fo", "Faroese"),

	/**
	 * International key, to use for localization, for <b>Filipino</b> language.
	 */
	FILIPINO("fil", "Filipino"),

	/**
	 * International key, to use for localization, for <b>Finnish</b> language.
	 */
	FINNISH("fin", "fi", "Finnish"),

	/**
	 * International key, to use for localization, for <b>French</b> language.
	 */
	FRENCH("fra", "fr", "French"),

	/**
	 * International key, to use for localization, for <b>Friulian</b> language.
	 */
	FRIULIAN("fur", "Friulian"),

	/**
	 * International key, to use for localization, for <b>Fulah</b> language.
	 */
	FULAH("ful", "ff", "Fulah"),

	/**
	 * International key, to use for localization, for <b>Galician</b> language.
	 */
	GALICIAN("glg", "gl", "Galician"),

	/**
	 * International key, to use for localization, for <b>Ganda</b> language.
	 */
	GANDA("lug", "lg", "Ganda"),

	/**
	 * International key, to use for localization, for <b>Georgian</b> language.
	 */
	GEORGIAN("kat", "ka", "Georgian"),

	/**
	 * International key, to use for localization, for <b>German</b> language.
	 */
	GERMAN("deu", "de", "German"),

	/**
	 * International key, to use for localization, for <b>Guarani</b> language.
	 */
	GUARANI("grn", "gn", "Guarani"),

	/**
	 * International key, to use for localization, for <b>Gujarati</b> language.
	 */
	GUJARATI("guj", "gu", "Gujarati"),

	/**
	 * International key, to use for localization, for <b>Gusii</b> language.
	 */
	GUSII("guz", "Gusii"),

	/**
	 * International key, to use for localization, for <b>Halh Mongolian</b> language.
	 */
	HALH_MONGOLIAN("khk", "Halh Mongolian"),

	/**
	 * International key, to use for localization, for <b>Hausa</b> language.
	 */
	HAUSA("hau", "ha", "Hausa"),

	/**
	 * International key, to use for localization, for <b>Hawaiian</b> language.
	 */
	HAWAIIAN("haw", "Hawaiian"),

	/**
	 * International key, to use for localization, for <b>Hebrew</b> language.
	 */
	HEBREW("heb", "he", "Hebrew"),

	/**
	 * International key, to use for localization, for <b>Hindi</b> language.
	 */
	HINDI("hin", "hi", "Hindi"),

	/**
	 * International key, to use for localization, for <b>Hungarian</b> language.
	 */
	HUNGARIAN("hun", "hu", "Hungarian"),

	/**
	 * International key, to use for localization, for <b>Icelandic</b> language.
	 */
	ICELANDIC("isl", "is", "Icelandic"),

	/**
	 * International key, to use for localization, for <b>Igbo</b> language.
	 */
	IGBO("ibo", "ig", "Igbo"),

	/**
	 * International key, to use for localization, for <b>Inari Sami</b> language.
	 */
	INARI_SAMI("smn", "Inari Sami"),

	/**
	 * International key, to use for localization, for <b>Indonesian</b> language.
	 */
	INDONESIAN("ind", "id", "Indonesian"),

	/**
	 * International key, to use for localization, for <b>Interlingua (International Auxiliary Language Association)</b> language.
	 */
	INTERLINGUA("ina", "ia", "Interlingua (International Auxiliary Language Association)"),

	/**
	 * International key, to use for localization, for <b>Inuktitut</b> language.
	 */
	INUKTITUT("iku", "iu", "Inuktitut"),

	/**
	 * International key, to use for localization, for <b>Iranian Persian</b> language.
	 */
	IRANIAN_PERSIAN("pes", "Iranian Persian"),

	/**
	 * International key, to use for localization, for <b>Irish</b> language.
	 */
	IRISH("gle", "ga", "Irish"),

	/**
	 * International key, to use for localization, for <b>Italian</b> language.
	 */
	ITALIAN("ita", "it", "Italian"),

	/**
	 * International key, to use for localization, for <b>Japanese</b> language.
	 */
	JAPANESE("jpn", "ja", "Japanese"),

	/**
	 * International key, to use for localization, for <b>Javanese</b> language.
	 */
	JAVANESE("jav", "jv", "Javanese"),

	/**
	 * International key, to use for localization, for <b>Jola-Fonyi</b> language.
	 */
	JOLA_FONYI("dyo", "Jola-Fonyi"),

	/**
	 * International key, to use for localization, for <b>K'iche'</b> language.
	 */
	KICHE("quc", "K'iche'"),

	/**
	 * International key, to use for localization, for <b>Kabuverdianu</b> language.
	 */
	KABUVERDIANU("kea", "Kabuverdianu"),

	/**
	 * International key, to use for localization, for <b>Kabyle</b> language.
	 */
	KABYLE("kab", "Kabyle"),

	/**
	 * International key, to use for localization, for <b>Kako</b> language.
	 */
	KAKO("kkj", "Kako"),

	/**
	 * International key, to use for localization, for <b>Kalaallisut</b> language.
	 */
	KALAALLISUT("kal", "kl", "Kalaallisut"),

	/**
	 * International key, to use for localization, for <b>Kalenjin</b> language.
	 */
	KALENJIN("kln", "Kalenjin"),

	/**
	 * International key, to use for localization, for <b>Kamba (Kenya)</b> language.
	 */
	KAMBA("kam", "Kamba (Kenya)"),

	/**
	 * International key, to use for localization, for <b>Kannada</b> language.
	 */
	KANNADA("kan", "kn", "Kannada"),

	/**
	 * International key, to use for localization, for <b>Kashmiri</b> language.
	 */
	KASHMIRI("kas", "ks", "Kashmiri"),

	/**
	 * International key, to use for localization, for <b>Kazakh</b> language.
	 */
	KAZAKH("kaz", "kk", "Kazakh"),

	/**
	 * International key, to use for localization, for <b>Khmer</b> language.
	 */
	KHMER("khm", "km", "Khmer"),

	/**
	 * International key, to use for localization, for <b>Khoekhoe</b> language.
	 */
	KHOEKHOE("naq", "Khoekhoe"),

	/**
	 * International key, to use for localization, for <b>Kikuyu</b> language.
	 */
	KIKUYU("kik", "ki", "Kikuyu"),

	/**
	 * International key, to use for localization, for <b>Kinyarwanda</b> language.
	 */
	KINYARWANDA("kin", "rw", "Kinyarwanda"),

	/**
	 * International key, to use for localization, for <b>Kirghiz</b> language.
	 */
	KIRGHIZ("kir", "ky", "Kirghiz"),

	/**
	 * International key, to use for localization, for <b>Konkani (individual language)</b> language.
	 */
	KONKANI_INDIVIDUAL("knn", "Konkani (individual language)"),

	/**
	 * International key, to use for localization, for <b>Konkani (macrolanguage)</b> language.
	 */
	KONKANI_MACRO("kok", "Konkani (macrolanguage)"),

	/**
	 * International key, to use for localization, for <b>Korean</b> language.
	 */
	KOREAN("kor", "ko", "Korean"),

	/**
	 * International key, to use for localization, for <b>Koyra Chiini Songhay</b> language.
	 */
	KOYRA_CHIINI_SONGHAY("khq", "Koyra Chiini Songhay"),

	/**
	 * International key, to use for localization, for <b>Koyraboro Senni Songhai</b> language.
	 */
	KOYRABORO_SENNI_SONGHAI("ses", "Koyraboro Senni Songhai"),

	/**
	 * International key, to use for localization, for <b>Kurdish</b> language.
	 */
	KURDISH("kur", "ku", "Kurdish"),

	/**
	 * International key, to use for localization, for <b>Kwasio</b> language.
	 */
	KWASIO("nmg", "Kwasio"),

	/**
	 * International key, to use for localization, for <b>KÃ¶lsch</b> language.
	 */
	KALSCH("ksh", "KÃ¶lsch"),

	/**
	 * International key, to use for localization, for <b>Lakota</b> language.
	 */
	LAKOTA("lkt", "Lakota"),

	/**
	 * International key, to use for localization, for <b>Langi</b> language.
	 */
	LANGI("lag", "Langi"),

	/**
	 * International key, to use for localization, for <b>Lao</b> language.
	 */
	LAO("lao", "lo", "Lao"),

	/**
	 * International key, to use for localization, for <b>Latvian</b> language.
	 */
	LATVIAN("lav", "lv", "Latvian"),

	/**
	 * International key, to use for localization, for <b>Lingala</b> language.
	 */
	LINGALA("lin", "ln", "Lingala"),

	/**
	 * International key, to use for localization, for <b>Lithuanian</b> language.
	 */
	LITHUANIAN("lit", "lt", "Lithuanian"),

	/**
	 * International key, to use for localization, for <b>Low German</b> language.
	 */
	LOW_GERMAN("nds", "Low German"),

	/**
	 * International key, to use for localization, for <b>Lower Sorbian</b> language.
	 */
	LOWER_SORBIAN("dsb", "Lower Sorbian"),

	/**
	 * International key, to use for localization, for <b>Luba-Katanga</b> language.
	 */
	LUBA_KATANGA("lub", "lu", "Luba-Katanga"),

	/**
	 * International key, to use for localization, for <b>Lule Sami</b> language.
	 */
	LULE_SAMI("smj", "Lule Sami"),

	/**
	 * International key, to use for localization, for <b>Luo (Kenya and Tanzania)</b> language.
	 */
	LUO("luo", "Luo (Kenya and Tanzania)"),

	/**
	 * International key, to use for localization, for <b>Luxembourgish</b> language.
	 */
	LUXEMBOURGISH("ltz", "lb", "Luxembourgish"),

	/**
	 * International key, to use for localization, for <b>Luyia</b> language.
	 */
	LUYIA("luy", "Luyia"),

	/**
	 * International key, to use for localization, for <b>Macedonian</b> language.
	 */
	MACEDONIAN("mkd", "mk", "Macedonian"),

	/**
	 * International key, to use for localization, for <b>Machame</b> language.
	 */
	MACHAME("jmc", "Machame"),

	/**
	 * International key, to use for localization, for <b>Maithili</b> language.
	 */
	MAITHILI("mai", "Maithili"),

	/**
	 * International key, to use for localization, for <b>Makhuwa-Meetto</b> language.
	 */
	MAKHUWA_MEETTO("mgh", "Makhuwa-Meetto"),

	/**
	 * International key, to use for localization, for <b>Makonde</b> language.
	 */
	MAKONDE("kde", "Makonde"),

	/**
	 * International key, to use for localization, for <b>Malagasy</b> language.
	 */
	MALAGASY("mlg", "mg", "Malagasy"),

	/**
	 * International key, to use for localization, for <b>Malay (macrolanguage)</b> language.
	 */
	MALAY("msa", "ms", "Malay (macrolanguage)"),

	/**
	 * International key, to use for localization, for <b>Malayalam</b> language.
	 */
	MALAYALAM("mal", "ml", "Malayalam"),

	/**
	 * International key, to use for localization, for <b>Maltese</b> language.
	 */
	MALTESE("mlt", "mt", "Maltese"),

	/**
	 * International key, to use for localization, for <b>Mandarin Chinese</b> language.
	 */
	MANDARIN("cmn", "Mandarin Chinese"),

	/**
	 * International key, to use for localization, for <b>Manipuri</b> language.
	 */
	MANIPURI("mni", "Manipuri"),

	/**
	 * International key, to use for localization, for <b>Manx</b> language.
	 */
	MANX("glv", "gv", "Manx"),

	/**
	 * International key, to use for localization, for <b>Maori</b> language.
	 */
	MAORI("mri", "mi", "Maori"),

	/**
	 * International key, to use for localization, for <b>Mapudungun</b> language.
	 */
	MAPUDUNGUN("arn", "Mapudungun"),

	/**
	 * International key, to use for localization, for <b>Marathi</b> language.
	 */
	MARATHI("mar", "mr", "Marathi"),

	/**
	 * International key, to use for localization, for <b>Masai</b> language.
	 */
	MASAI("mas", "Masai"),

	/**
	 * International key, to use for localization, for <b>Mazanderani</b> language.
	 */
	MAZANDERANI("mzn", "Mazanderani"),

	/**
	 * International key, to use for localization, for <b>Meru</b> language.
	 */
	MERU("mer", "Meru"),

	/**
	 * International key, to use for localization, for <b>Meta'</b> language.
	 */
	META("mgo", "Meta'"),

	/**
	 * International key, to use for localization, for <b>Modern Greek (1453-)</b> language.
	 */
	MODERN_GREEK("ell", "el", "Modern Greek (1453-)"),

	/**
	 * International key, to use for localization, for <b>Mohawk</b> language.
	 */
	MOHAWK("moh", "Mohawk"),

	/**
	 * International key, to use for localization, for <b>Mongolian</b> language.
	 */
	MONGOLIAN("mon", "mn", "Mongolian"),

	/**
	 * International key, to use for localization, for <b>Montenegrin</b> language.
	 */
	MONTENEGRIN("cnr", "Montenegrin"),

	/**
	 * International key, to use for localization, for <b>Morisyen</b> language.
	 */
	MORISYEN("mfe", "Morisyen"),

	/**
	 * International key, to use for localization, for <b>Mundang</b> language.
	 */
	MUNDANG("mua", "Mundang"),

	/**
	 * International key, to use for localization, for <b>N'Ko</b> language.
	 */
	NKO("nqo", "N'Ko"),

	/**
	 * International key, to use for localization, for <b>Nepali (individual language)</b> language.
	 */
	NEPALI_INDIVIDUAL("npi", "Nepali (individual language)"),

	/**
	 * International key, to use for localization, for <b>Nepali (macrolanguage)</b> language.
	 */
	NEPALI_MACRO("nep", "ne", "Nepali (macrolanguage)"),

	/**
	 * International key, to use for localization, for <b>Ngiemboon</b> language.
	 */
	NGIEMBOON("nnh", "Ngiemboon"),

	/**
	 * International key, to use for localization, for <b>Ngomba</b> language.
	 */
	NGOMBA("jgo", "Ngomba"),

	/**
	 * International key, to use for localization, for <b>Nigerian Pidgin</b> language.
	 */
	NIGERIAN_PIDGIN("pcm", "Nigerian Pidgin"),

	/**
	 * International key, to use for localization, for <b>North Azerbaijani</b> language.
	 */
	NORTH_AZERBAIJANI("azj", "North Azerbaijani"),

	/**
	 * International key, to use for localization, for <b>North Ndebele</b> language.
	 */
	NORTH_NDEBELE("nde", "nd", "North Ndebele"),

	/**
	 * International key, to use for localization, for <b>Northern Kurdish</b> language.
	 */
	NORTHERN_KURDISH("kmr", "Northern Kurdish"),

	/**
	 * International key, to use for localization, for <b>Northern Luri</b> language.
	 */
	NORTHERN_LURI("lrc", "Northern Luri"),

	/**
	 * International key, to use for localization, for <b>Northern Pashto</b> language.
	 */
	NORTHERN_PASHTO("pbu", "Northern Pashto"),

	/**
	 * International key, to use for localization, for <b>Northern Sami</b> language.
	 */
	NORTHERN_SAMI("sme", "se", "Northern Sami"),

	/**
	 * International key, to use for localization, for <b>Northern Uzbek</b> language.
	 */
	NORTHERN_UZBEK("uzn", "Northern Uzbek"),

	/**
	 * International key, to use for localization, for <b>Norwegian</b> language.
	 */
	NORWEGIAN("nor", "no", "Norwegian"),

	/**
	 * International key, to use for localization, for <b>Norwegian BokmÃ¥l</b> language.
	 */
	NORWEGIAN_BOKMAL("nob", "nb", "Norwegian BokmÃ¥l"),

	/**
	 * International key, to use for localization, for <b>Norwegian Nynorsk</b> language.
	 */
	NORWEGIAN_NYNORSK("nno", "nn", "Norwegian Nynorsk"),

	/**
	 * International key, to use for localization, for <b>Nuer</b> language.
	 */
	NUER("nus", "Nuer"),

	/**
	 * International key, to use for localization, for <b>Nyankole</b> language.
	 */
	NYANKOLE("nyn", "Nyankole"),

	/**
	 * International key, to use for localization, for <b>Occitan (post 1500)</b> language.
	 */
	OCCITAN("oci", "oc", "Occitan (post 1500)"),

	/**
	 * International key, to use for localization, for <b>Odia</b> language.
	 */
	ODIA("ory", "Odia"),

	/**
	 * International key, to use for localization, for <b>Oriya (macrolanguage)</b> language.
	 */
	ORIYA("ori", "or", "Oriya (macrolanguage)"),

	/**
	 * International key, to use for localization, for <b>Oromo</b> language.
	 */
	OROMO("orm", "om", "Oromo"),

	/**
	 * International key, to use for localization, for <b>Ossetian</b> language.
	 */
	OSSETIAN("oss", "os", "Ossetian"),

	/**
	 * International key, to use for localization, for <b>Panjabi</b> language.
	 */
	PANJABI("pan", "pa", "Panjabi"),

	/**
	 * International key, to use for localization, for <b>Pedi</b> language.
	 */
	PEDI("nso", "Pedi"),

	/**
	 * International key, to use for localization, for <b>Persian</b> language.
	 */
	PERSIAN("fas", "fa", "Persian"),

	/**
	 * International key, to use for localization, for <b>Plateau Malagasy</b> language.
	 */
	PLATEAU_MALAGASY("plt", "Plateau Malagasy"),

	/**
	 * International key, to use for localization, for <b>Polish</b> language.
	 */
	POLISH("pol", "pl", "Polish"),

	/**
	 * International key, to use for localization, for <b>Portuguese</b> language.
	 */
	PORTUGUESE("por", "pt", "Portuguese"),

	/**
	 * International key, to use for localization, for <b>Prussian</b> language.
	 */
	PRUSSIAN("prg", "Prussian"),

	/**
	 * International key, to use for localization, for <b>Pulaar</b> language.
	 */
	PULAAR("fuc", "Pulaar"),

	/**
	 * International key, to use for localization, for <b>Pushto</b> language.
	 */
	PUSHTO("pus", "ps", "Pushto"),

	/**
	 * International key, to use for localization, for <b>Quechua</b> language.
	 */
	QUECHUA("que", "qu", "Quechua"),

	/**
	 * International key, to use for localization, for <b>Romanian</b> language.
	 */
	ROMANIAN("ron", "ro", "Romanian"),

	/**
	 * International key, to use for localization, for <b>Romansh</b> language.
	 */
	ROMANSH("roh", "rm", "Romansh"),

	/**
	 * International key, to use for localization, for <b>Rombo</b> language.
	 */
	ROMBO("rof", "Rombo"),

	/**
	 * International key, to use for localization, for <b>Rundi</b> language.
	 */
	RUNDI("run", "rn", "Rundi"),

	/**
	 * International key, to use for localization, for <b>Russian</b> language.
	 */
	RUSSIAN("rus", "ru", "Russian"),

	/**
	 * International key, to use for localization, for <b>Rwa</b> language.
	 */
	RWA("rwk", "Rwa"),

	/**
	 * International key, to use for localization, for <b>Sabaot</b> language.
	 */
	SABAOT("spy", "Sabaot"),

	/**
	 * International key, to use for localization, for <b>Saho</b> language.
	 */
	SAHO("ssy", "Saho"),

	/**
	 * International key, to use for localization, for <b>Samburu</b> language.
	 */
	SAMBURU("saq", "Samburu"),

	/**
	 * International key, to use for localization, for <b>Sango</b> language.
	 */
	SANGO("sag", "sg", "Sango"),

	/**
	 * International key, to use for localization, for <b>Sangu (Tanzania)</b> language.
	 */
	SANGU("sbp", "Sangu (Tanzania)"),

	/**
	 * International key, to use for localization, for <b>Sanskrit</b> language.
	 */
	SANSKRIT("san", "sa", "Sanskrit"),

	/**
	 * International key, to use for localization, for <b>Santali</b> language.
	 */
	SANTALI("sat", "Santali"),

	/**
	 * International key, to use for localization, for <b>Scottish Gaelic</b> language.
	 */
	SCOTTISH_GAELIC("gla", "gd", "Scottish Gaelic"),

	/**
	 * International key, to use for localization, for <b>Sena</b> language.
	 */
	SENA("seh", "Sena"),

	/**
	 * International key, to use for localization, for <b>Serbian</b> language.
	 */
	SERBIAN("srp", "sr", "Serbian"),

	/**
	 * International key, to use for localization, for <b>Serbo-Croatian</b> language.
	 */
	SERBO_CROATIAN("hbs", "sh", "Serbo-Croatian"),

	/**
	 * International key, to use for localization, for <b>Shambala</b> language.
	 */
	SHAMBALA("ksb", "Shambala"),

	/**
	 * International key, to use for localization, for <b>Shona</b> language.
	 */
	SHONA("sna", "sn", "Shona"),

	/**
	 * International key, to use for localization, for <b>Sichuan Yi</b> language.
	 */
	SICHUAN_YI("iii", "ii", "Sichuan Yi"),

	/**
	 * International key, to use for localization, for <b>Sindhi</b> language.
	 */
	SINDHI("snd", "sd", "Sindhi"),

	/**
	 * International key, to use for localization, for <b>Sinhala</b> language.
	 */
	SINHALA("sin", "si", "Sinhala"),

	/**
	 * International key, to use for localization, for <b>Skolt Sami</b> language.
	 */
	SKOLT_SAMI("sms", "Skolt Sami"),

	/**
	 * International key, to use for localization, for <b>Slovak</b> language.
	 */
	SLOVAK("slk", "sk", "Slovak"),

	/**
	 * International key, to use for localization, for <b>Slovenian</b> language.
	 */
	SLOVENIAN("slv", "sl", "Slovenian"),

	/**
	 * International key, to use for localization, for <b>Soga</b> language.
	 */
	SOGA("xog", "Soga"),

	/**
	 * International key, to use for localization, for <b>Somali</b> language.
	 */
	SOMALI("som", "so", "Somali"),

	/**
	 * International key, to use for localization, for <b>South Ndebele</b> language.
	 */
	SOUTH_NDEBELE("nbl", "nr", "South Ndebele"),

	/**
	 * International key, to use for localization, for <b>Southern Sami</b> language.
	 */
	SOUTHERN_SAMI("sma", "Southern Sami"),

	/**
	 * International key, to use for localization, for <b>Southern Sotho</b> language.
	 */
	SOUTHERN_SOTHO("sot", "st", "Southern Sotho"),

	/**
	 * International key, to use for localization, for <b>Spanish</b> language.
	 */
	SPANISH("spa", "es", "Spanish"),

	/**
	 * International key, to use for localization, for <b>Standard Arabic</b> language.
	 */
	STANDARD_ARABIC("arb", "Standard Arabic"),

	/**
	 * International key, to use for localization, for <b>Standard Estonian</b> language.
	 */
	STANDARD_ESTONIAN("ekk", "Standard Estonian"),

	/**
	 * International key, to use for localization, for <b>Standard Latvian</b> language.
	 */
	STANDARD_LATVIAN("lvs", "Standard Latvian"),

	/**
	 * International key, to use for localization, for <b>Standard Malay</b> language.
	 */
	STANDARD_MALAY("zsm", "Standard Malay"),

	/**
	 * International key, to use for localization, for <b>Standard Moroccan Tamazight</b> language.
	 */
	STANDARD_MOROCCAN_TAMAZIGHT("zgh", "Standard Moroccan Tamazight"),

	/**
	 * International key, to use for localization, for <b>Sundanese</b> language.
	 */
	SUNDANESE("sun", "su", "Sundanese"),

	/**
	 * International key, to use for localization, for <b>Swahili (individual language)</b> language.
	 */
	SWAHILI_INDIVIDUAL("swh", "Swahili (individual language)"),

	/**
	 * International key, to use for localization, for <b>Swahili (macrolanguage)</b> language.
	 */
	SWAHILI_MACRO("swa", "sw", "Swahili (macrolanguage)"),

	/**
	 * International key, to use for localization, for <b>Swati</b> language.
	 */
	SWATI("ssw", "ss", "Swati"),

	/**
	 * International key, to use for localization, for <b>Swedish</b> language.
	 */
	SWEDISH("swe", "sv", "Swedish"),

	/**
	 * International key, to use for localization, for <b>Swiss German</b> language.
	 */
	SWISS_GERMAN("gsw", "Swiss German"),

	/**
	 * International key, to use for localization, for <b>Syriac</b> language.
	 */
	SYRIAC("syr", "Syriac"),

	/**
	 * International key, to use for localization, for <b>Tachelhit</b> language.
	 */
	TACHELHIT("shi", "Tachelhit"),

	/**
	 * International key, to use for localization, for <b>Tagalog</b> language.
	 */
	TAGALOG("tgl", "tl", "Tagalog"),

	/**
	 * International key, to use for localization, for <b>Taita</b> language.
	 */
	TAITA("dav", "Taita"),

	/**
	 * International key, to use for localization, for <b>Tajik</b> language.
	 */
	TAJIK("tgk", "tg", "Tajik"),

	/**
	 * International key, to use for localization, for <b>Tamil</b> language.
	 */
	TAMIL("tam", "ta", "Tamil"),

	/**
	 * International key, to use for localization, for <b>Tasawaq</b> language.
	 */
	TASAWAQ("twq", "Tasawaq"),

	/**
	 * International key, to use for localization, for <b>Tatar</b> language.
	 */
	TATAR("tat", "tt", "Tatar"),

	/**
	 * International key, to use for localization, for <b>Telugu</b> language.
	 */
	TELUGU("tel", "te", "Telugu"),

	/**
	 * International key, to use for localization, for <b>Teso</b> language.
	 */
	TESO("teo", "Teso"),

	/**
	 * International key, to use for localization, for <b>Thai</b> language.
	 */
	THAI("tha", "th", "Thai"),

	/**
	 * International key, to use for localization, for <b>Tibetan</b> language.
	 */
	TIBETAN("bod", "bo", "Tibetan"),

	/**
	 * International key, to use for localization, for <b>Tigre</b> language.
	 */
	TIGRE("tig", "Tigre"),

	/**
	 * International key, to use for localization, for <b>Tigrinya</b> language.
	 */
	TIGRINYA("tir", "ti", "Tigrinya"),

	/**
	 * International key, to use for localization, for <b>Tonga (Tonga Islands)</b> language.
	 */
	TONGA("ton", "to", "Tonga (Tonga Islands)"),

	/**
	 * International key, to use for localization, for <b>Tosk Albanian</b> language.
	 */
	TOSK_ALBANIAN("als", "Tosk Albanian"),

	/**
	 * International key, to use for localization, for <b>Tsonga</b> language.
	 */
	TSONGA("tso", "ts", "Tsonga"),

	/**
	 * International key, to use for localization, for <b>Tswana</b> language.
	 */
	TSWANA("tsn", "tn", "Tswana"),

	/**
	 * International key, to use for localization, for <b>Turkish</b> language.
	 */
	TURKISH("tur", "tr", "Turkish"),

	/**
	 * International key, to use for localization, for <b>Turkmen</b> language.
	 */
	TURKMEN("tuk", "tk", "Turkmen"),

	/**
	 * International key, to use for localization, for <b>Twi</b> language.
	 */
	TWI("twi", "tw", "Twi"),

	/**
	 * International key, to use for localization, for <b>Uighur</b> language.
	 */
	UIGHUR("uig", "ug", "Uighur"),

	/**
	 * International key, to use for localization, for <b>Ukrainian</b> language.
	 */
	UKRAINIAN("ukr", "uk", "Ukrainian"),

	/**
	 * International key, to use for localization, for <b>Upper Sorbian</b> language.
	 */
	UPPER_SORBIAN("hsb", "Upper Sorbian"),

	/**
	 * International key, to use for localization, for <b>Urdu</b> language.
	 */
	URDU("urd", "ur", "Urdu"),

	/**
	 * International key, to use for localization, for <b>Uzbek</b> language.
	 */
	UZBEK("uzb", "uz", "Uzbek"),

	/**
	 * International key, to use for localization, for <b>Vai</b> language.
	 */
	VAI("vai", "Vai"),

	/**
	 * International key, to use for localization, for <b>Venda</b> language.
	 */
	VENDA("ven", "ve", "Venda"),

	/**
	 * International key, to use for localization, for <b>Vietnamese</b> language.
	 */
	VIETNAMESE("vie", "vi", "Vietnamese"),

	/**
	 * International key, to use for localization, for <b>VolapÃ¼k</b> language.
	 */
	VOLAPAK("vol", "vo", "VolapÃ¼k"),

	/**
	 * International key, to use for localization, for <b>Vunjo</b> language.
	 */
	VUNJO("vun", "Vunjo"),

	/**
	 * International key, to use for localization, for <b>Walser</b> language.
	 */
	WALSER("wae", "Walser"),

	/**
	 * International key, to use for localization, for <b>Welsh</b> language.
	 */
	WELSH("cym", "cy", "Welsh"),

	/**
	 * International key, to use for localization, for <b>West Central Oromo</b> language.
	 */
	WEST_CENTRAL_OROMO("gaz", "West Central Oromo"),

	/**
	 * International key, to use for localization, for <b>Western Frisian</b> language.
	 */
	WESTERN_FRISIAN("fry", "fy", "Western Frisian"),

	/**
	 * International key, to use for localization, for <b>Wolaytta</b> language.
	 */
	WOLAYTTA("wal", "Wolaytta"),

	/**
	 * International key, to use for localization, for <b>Wolof</b> language.
	 */
	WOLOF("wol", "wo", "Wolof"),

	/**
	 * International key, to use for localization, for <b>Xhosa</b> language.
	 */
	XHOSA("xho", "xh", "Xhosa"),

	/**
	 * International key, to use for localization, for <b>Yakut</b> language.
	 */
	YAKUT("sah", "Yakut"),

	/**
	 * International key, to use for localization, for <b>Yangben</b> language.
	 */
	YANGBEN("yav", "Yangben"),

	/**
	 * International key, to use for localization, for <b>Yiddish</b> language.
	 */
	YIDDISH("yid", "yi", "Yiddish"),

	/**
	 * International key, to use for localization, for <b>Yoruba</b> language.
	 */
	YORUBA("yor", "yo", "Yoruba"),

	/**
	 * International key, to use for localization, for <b>Yue Chinese</b> language.
	 */
	YUE_CHINESE("yue", "Yue Chinese"),

	/**
	 * International key, to use for localization, for <b>Zarma</b> language.
	 */
	ZARMA("dje", "Zarma"),

	/**
	 * International key, to use for localization, for <b>Zulu</b> language.
	 */
	ZULU("zul", "zu", "Zulu");

	// identifier 3 chars
	private final String code3chars;
	// identifier 2 chars
	private final String code2chars;
	// name of language
	private final String name;
	// value for key
	private final String value;

	/**
	 * Creates the object with identifier (3 chars) and its name.
	 * 
	 * @param code3chars language identifier, 3 chars
	 * @param name name of the language
	 */
	private Language(String code3chars, String name) {
		this(code3chars, null, name);
	}

	/**
	 * Creates the object with identifiers (3 and 2 chars) and its name.
	 * 
	 * @param code3chars language identifier, 3 chars
	 * @param code2chars language identifier, 2 chars
	 * @param name name of the language
	 */
	private Language(String code3chars, String code2chars, String name) {
		this.code3chars = code3chars;
		this.code2chars = code2chars;
		this.name = name;
		// for the value to use
		// if the 2 digits is present, use 2 digits
		// otherwise 3 digits
		this.value = code2chars != null ? code2chars : code3chars;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.commons.Key#value()
	 */
	@Override
	public String value() {
		return value;
	}

	/**
	 * Returns the language identifier, 3 chars.
	 * 
	 * @return the language identifier, 3 chars
	 */
	public String getCode3Chars() {
		return code3chars;
	}

	/**
	 * Returns the language identifier, 2 chars.<br>
	 * It could be <code>null</code>.
	 * 
	 * @return the language identifier, 2 chars.<br>
	 *         It could be <code>null</code>
	 */
	public String getCode2Chars() {
		return code2chars;
	}

	/**
	 * Returns the name of the language.
	 * 
	 * @return the name of the language
	 */
	@Override
	public String getName() {
		return name;
	}

	/**
	 * Returns the language instance, found using the identifier argument which is checked against both cods, 2 and 3 chars.
	 * 
	 * @param identifier language identifier to search
	 * @return the language instance or <code>null</code> if not exists
	 */
	public static Language getByCode(String identifier) {
		// checks if passed identifier is consistent
		if (identifier != null && identifier.trim().length() > 0) {
			// scans the languages
			for (Language language : values()) {
				// checks if language is equals to argument
				// checking the 2 and 3 chars identifier
				if (language.value().equalsIgnoreCase(identifier) || language.getCode3Chars().equalsIgnoreCase(identifier)) {
					return language;
				}
			}
		}
		// if here the identifier argument is not consistent
		// or the identifier does not exist
		// then returns null
		return null;
	}

}