/**
    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
      http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.pepstock.charba.client.intl.enums;

import org.pepstock.charba.client.intl.IsLocaleItem;

/**
 * Enumerates the standard codes for script identification which can be used to create and manage locale.
 * 
 * @author Andrea "Stock" Stocchero
 */
public enum Currency implements IsLocaleItem
{
	/**
	 * International key, to use for localization, for <b>ADB Unit of Account</b> currency.
	 */
	ADB_UNIT_OF_ACCOUNT("XUA", "ADB Unit of Account", 2),

	/**
	 * International key, to use for localization, for <b>Afghani</b> currency.
	 */
	AFGHANI("AFN", "Afghani", 2),

	/**
	 * International key, to use for localization, for <b>Algerian Dinar</b> currency.
	 */
	ALGERIAN_DINAR("DZD", "Algerian Dinar", 2),

	/**
	 * International key, to use for localization, for <b>Argentine Peso</b> currency.
	 */
	ARGENTINE_PESO("ARS", "Argentine Peso", 2),

	/**
	 * International key, to use for localization, for <b>Armenian Dram</b> currency.
	 */
	ARMENIAN_DRAM("AMD", "Armenian Dram", 2),

	/**
	 * International key, to use for localization, for <b>Aruban Florin</b> currency.
	 */
	ARUBAN_FLORIN("AWG", "Aruban Florin", 2),

	/**
	 * International key, to use for localization, for <b>Australian Dollar</b> currency.
	 */
	AUSTRALIAN_DOLLAR("AUD", "Australian Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Azerbaijan Manat</b> currency.
	 */
	AZERBAIJAN_MANAT("AZN", "Azerbaijan Manat", 2),

	/**
	 * International key, to use for localization, for <b>Bahamian Dollar</b> currency.
	 */
	BAHAMIAN_DOLLAR("BSD", "Bahamian Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Bahraini Dinar</b> currency.
	 */
	BAHRAINI_DINAR("BHD", "Bahraini Dinar", 3),

	/**
	 * International key, to use for localization, for <b>Baht</b> currency.
	 */
	BAHT("THB", "Baht", 2),

	/**
	 * International key, to use for localization, for <b>Balboa</b> currency.
	 */
	BALBOA("PAB", "Balboa", 2),

	/**
	 * International key, to use for localization, for <b>Barbados Dollar</b> currency.
	 */
	BARBADOS_DOLLAR("BBD", "Barbados Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Belarusian Ruble</b> currency.
	 */
	BELARUSIAN_RUBLE("BYN", "Belarusian Ruble", 2),

	/**
	 * International key, to use for localization, for <b>Belize Dollar</b> currency.
	 */
	BELIZE_DOLLAR("BZD", "Belize Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Bermudian Dollar</b> currency.
	 */
	BERMUDIAN_DOLLAR("BMD", "Bermudian Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Boliviano</b> currency.
	 */
	BOLIVIANO("BOB", "Boliviano", 2),

	/**
	 * International key, to use for localization, for <b>Bolívar Soberano</b> currency.
	 */
	BOLIVAR_SOBERANO("VES", "Bolívar Soberano", 2),

	/**
	 * International key, to use for localization, for <b>Bond Markets Unit European Composite Unit (EURCO)</b> currency.
	 */
	BOND_MARKETS_UNIT_EUROPEAN_COMPOSITE_UNIT("XBA", "Bond Markets Unit European Composite Unit (EURCO)", 2),

	/**
	 * International key, to use for localization, for <b>Bond Markets Unit European Monetary Unit (E.M.U.-6)</b> currency.
	 */
	BOND_MARKETS_UNIT_EUROPEAN_MONETARY_UNIT("XBB", "Bond Markets Unit European Monetary Unit (E.M.U.-6)", 2),

	/**
	 * International key, to use for localization, for <b>Bond Markets Unit European Unit of Account 17 (E.U.A.-17)</b> currency.
	 */
	BOND_MARKETS_UNIT_EUROPEAN_UNIT_OF_ACCOUNT_17("XBD", "Bond Markets Unit European Unit of Account 17 (E.U.A.-17)", 2),

	/**
	 * International key, to use for localization, for <b>Bond Markets Unit European Unit of Account 9 (E.U.A.-9)</b> currency.
	 */
	BOND_MARKETS_UNIT_EUROPEAN_UNIT_OF_ACCOUNT_9("XBC", "Bond Markets Unit European Unit of Account 9 (E.U.A.-9)", 2),

	/**
	 * International key, to use for localization, for <b>Brazilian Real</b> currency.
	 */
	BRAZILIAN_REAL("BRL", "Brazilian Real", 2),

	/**
	 * International key, to use for localization, for <b>Brunei Dollar</b> currency.
	 */
	BRUNEI_DOLLAR("BND", "Brunei Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Bulgarian Lev</b> currency.
	 */
	BULGARIAN_LEV("BGN", "Bulgarian Lev", 2),

	/**
	 * International key, to use for localization, for <b>Burundi Franc</b> currency.
	 */
	BURUNDI_FRANC("BIF", "Burundi Franc", 0),

	/**
	 * International key, to use for localization, for <b>CFA Franc BCEAO</b> currency.
	 */
	CFA_FRANC_BCEAO("XOF", "CFA Franc BCEAO", 0),

	/**
	 * International key, to use for localization, for <b>CFA Franc BEAC</b> currency.
	 */
	CFA_FRANC_BEAC("XAF", "CFA Franc BEAC", 0),

	/**
	 * International key, to use for localization, for <b>CFP Franc</b> currency.
	 */
	CFP_FRANC("XPF", "CFP Franc", 0),

	/**
	 * International key, to use for localization, for <b>Cabo Verde Escudo</b> currency.
	 */
	CABO_VERDE_ESCUDO("CVE", "Cabo Verde Escudo", 2),

	/**
	 * International key, to use for localization, for <b>Canadian Dollar</b> currency.
	 */
	CANADIAN_DOLLAR("CAD", "Canadian Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Cayman Islands Dollar</b> currency.
	 */
	CAYMAN_ISLANDS_DOLLAR("KYD", "Cayman Islands Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Chilean Peso</b> currency.
	 */
	CHILEAN_PESO("CLP", "Chilean Peso", 0),

	/**
	 * International key, to use for localization, for <b>Codes specifically reserved for testing purposes</b> currency.
	 */
	CODES_SPECIFICALLY_RESERVED_FOR_TESTING_PURPOSES("XTS", "Codes specifically reserved for testing purposes", 2),

	/**
	 * International key, to use for localization, for <b>Colombian Peso</b> currency.
	 */
	COLOMBIAN_PESO("COP", "Colombian Peso", 2),

	/**
	 * International key, to use for localization, for <b>Comorian Franc </b> currency.
	 */
	COMORIAN_FRANC("KMF", "Comorian Franc ", 0),

	/**
	 * International key, to use for localization, for <b>Congolese Franc</b> currency.
	 */
	CONGOLESE_FRANC("CDF", "Congolese Franc", 2),

	/**
	 * International key, to use for localization, for <b>Convertible Mark</b> currency.
	 */
	CONVERTIBLE_MARK("BAM", "Convertible Mark", 2),

	/**
	 * International key, to use for localization, for <b>Cordoba Oro</b> currency.
	 */
	CORDOBA_ORO("NIO", "Cordoba Oro", 2),

	/**
	 * International key, to use for localization, for <b>Costa Rican Colon</b> currency.
	 */
	COSTA_RICAN_COLON("CRC", "Costa Rican Colon", 2),

	/**
	 * International key, to use for localization, for <b>Cuban Peso</b> currency.
	 */
	CUBAN_PESO("CUP", "Cuban Peso", 2),

	/**
	 * International key, to use for localization, for <b>Czech Koruna</b> currency.
	 */
	CZECH_KORUNA("CZK", "Czech Koruna", 2),

	/**
	 * International key, to use for localization, for <b>Dalasi</b> currency.
	 */
	DALASI("GMD", "Dalasi", 2),

	/**
	 * International key, to use for localization, for <b>Danish Krone</b> currency.
	 */
	DANISH_KRONE("DKK", "Danish Krone", 2),

	/**
	 * International key, to use for localization, for <b>Denar</b> currency.
	 */
	DENAR("MKD", "Denar", 2),

	/**
	 * International key, to use for localization, for <b>Djibouti Franc</b> currency.
	 */
	DJIBOUTI_FRANC("DJF", "Djibouti Franc", 0),

	/**
	 * International key, to use for localization, for <b>Dobra</b> currency.
	 */
	DOBRA("STN", "Dobra", 2),

	/**
	 * International key, to use for localization, for <b>Dominican Peso</b> currency.
	 */
	DOMINICAN_PESO("DOP", "Dominican Peso", 2),

	/**
	 * International key, to use for localization, for <b>Dong</b> currency.
	 */
	DONG("VND", "Dong", 0),

	/**
	 * International key, to use for localization, for <b>East Caribbean Dollar</b> currency.
	 */
	EAST_CARIBBEAN_DOLLAR("XCD", "East Caribbean Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Egyptian Pound</b> currency.
	 */
	EGYPTIAN_POUND("EGP", "Egyptian Pound", 2),

	/**
	 * International key, to use for localization, for <b>El Salvador Colon</b> currency.
	 */
	EL_SALVADOR_COLON("SVC", "El Salvador Colon", 2),

	/**
	 * International key, to use for localization, for <b>Ethiopian Birr</b> currency.
	 */
	ETHIOPIAN_BIRR("ETB", "Ethiopian Birr", 2),

	/**
	 * International key, to use for localization, for <b>Euro</b> currency.
	 */
	EURO("EUR", "Euro", 2),

	/**
	 * International key, to use for localization, for <b>Falkland Islands Pound</b> currency.
	 */
	FALKLAND_ISLANDS_POUND("FKP", "Falkland Islands Pound", 2),

	/**
	 * International key, to use for localization, for <b>Fiji Dollar</b> currency.
	 */
	FIJI_DOLLAR("FJD", "Fiji Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Forint</b> currency.
	 */
	FORINT("HUF", "Forint", 2),

	/**
	 * International key, to use for localization, for <b>Ghana Cedi</b> currency.
	 */
	GHANA_CEDI("GHS", "Ghana Cedi", 2),

	/**
	 * International key, to use for localization, for <b>Gibraltar Pound</b> currency.
	 */
	GIBRALTAR_POUND("GIP", "Gibraltar Pound", 2),

	/**
	 * International key, to use for localization, for <b>Gold</b> currency.
	 */
	GOLD("XAU", "Gold", 2),

	/**
	 * International key, to use for localization, for <b>Gourde</b> currency.
	 */
	GOURDE("HTG", "Gourde", 2),

	/**
	 * International key, to use for localization, for <b>Guarani</b> currency.
	 */
	GUARANI("PYG", "Guarani", 0),

	/**
	 * International key, to use for localization, for <b>Guinean Franc</b> currency.
	 */
	GUINEAN_FRANC("GNF", "Guinean Franc", 0),

	/**
	 * International key, to use for localization, for <b>Guyana Dollar</b> currency.
	 */
	GUYANA_DOLLAR("GYD", "Guyana Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Hong Kong Dollar</b> currency.
	 */
	HONG_KONG_DOLLAR("HKD", "Hong Kong Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Hryvnia</b> currency.
	 */
	HRYVNIA("UAH", "Hryvnia", 2),

	/**
	 * International key, to use for localization, for <b>Iceland Krona</b> currency.
	 */
	ICELAND_KRONA("ISK", "Iceland Krona", 0),

	/**
	 * International key, to use for localization, for <b>Indian Rupee</b> currency.
	 */
	INDIAN_RUPEE("INR", "Indian Rupee", 2),

	/**
	 * International key, to use for localization, for <b>Iranian Rial</b> currency.
	 */
	IRANIAN_RIAL("IRR", "Iranian Rial", 2),

	/**
	 * International key, to use for localization, for <b>Iraqi Dinar</b> currency.
	 */
	IRAQI_DINAR("IQD", "Iraqi Dinar", 3),

	/**
	 * International key, to use for localization, for <b>Jamaican Dollar</b> currency.
	 */
	JAMAICAN_DOLLAR("JMD", "Jamaican Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Jordanian Dinar</b> currency.
	 */
	JORDANIAN_DINAR("JOD", "Jordanian Dinar", 3),

	/**
	 * International key, to use for localization, for <b>Kenyan Shilling</b> currency.
	 */
	KENYAN_SHILLING("KES", "Kenyan Shilling", 2),

	/**
	 * International key, to use for localization, for <b>Kina</b> currency.
	 */
	KINA("PGK", "Kina", 2),

	/**
	 * International key, to use for localization, for <b>Kuna</b> currency.
	 */
	KUNA("HRK", "Kuna", 2),

	/**
	 * International key, to use for localization, for <b>Kuwaiti Dinar</b> currency.
	 */
	KUWAITI_DINAR("KWD", "Kuwaiti Dinar", 3),

	/**
	 * International key, to use for localization, for <b>Kwanza</b> currency.
	 */
	KWANZA("AOA", "Kwanza", 2),

	/**
	 * International key, to use for localization, for <b>Kyat</b> currency.
	 */
	KYAT("MMK", "Kyat", 2),

	/**
	 * International key, to use for localization, for <b>Lao Kip</b> currency.
	 */
	LAO_KIP("LAK", "Lao Kip", 2),

	/**
	 * International key, to use for localization, for <b>Lari</b> currency.
	 */
	LARI("GEL", "Lari", 2),

	/**
	 * International key, to use for localization, for <b>Lebanese Pound</b> currency.
	 */
	LEBANESE_POUND("LBP", "Lebanese Pound", 2),

	/**
	 * International key, to use for localization, for <b>Lek</b> currency.
	 */
	LEK("ALL", "Lek", 2),

	/**
	 * International key, to use for localization, for <b>Lempira</b> currency.
	 */
	LEMPIRA("HNL", "Lempira", 2),

	/**
	 * International key, to use for localization, for <b>Leone</b> currency.
	 */
	LEONE("SLL", "Leone", 2),

	/**
	 * International key, to use for localization, for <b>Liberian Dollar</b> currency.
	 */
	LIBERIAN_DOLLAR("LRD", "Liberian Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Libyan Dinar</b> currency.
	 */
	LIBYAN_DINAR("LYD", "Libyan Dinar", 3),

	/**
	 * International key, to use for localization, for <b>Lilangeni</b> currency.
	 */
	LILANGENI("SZL", "Lilangeni", 2),

	/**
	 * International key, to use for localization, for <b>Loti</b> currency.
	 */
	LOTI("LSL", "Loti", 2),

	/**
	 * International key, to use for localization, for <b>Malagasy Ariary</b> currency.
	 */
	MALAGASY_ARIARY("MGA", "Malagasy Ariary", 2),

	/**
	 * International key, to use for localization, for <b>Malawi Kwacha</b> currency.
	 */
	MALAWI_KWACHA("MWK", "Malawi Kwacha", 2),

	/**
	 * International key, to use for localization, for <b>Malaysian Ringgit</b> currency.
	 */
	MALAYSIAN_RINGGIT("MYR", "Malaysian Ringgit", 2),

	/**
	 * International key, to use for localization, for <b>Mauritius Rupee</b> currency.
	 */
	MAURITIUS_RUPEE("MUR", "Mauritius Rupee", 2),

	/**
	 * International key, to use for localization, for <b>Mexican Peso</b> currency.
	 */
	MEXICAN_PESO("MXN", "Mexican Peso", 2),

	/**
	 * International key, to use for localization, for <b>Mexican Unidad de Inversion (UDI)</b> currency.
	 */
	MEXICAN_UNIDAD_DE_INVERSION("MXV", "Mexican Unidad de Inversion (UDI)", 2),

	/**
	 * International key, to use for localization, for <b>Moldovan Leu</b> currency.
	 */
	MOLDOVAN_LEU("MDL", "Moldovan Leu", 2),

	/**
	 * International key, to use for localization, for <b>Moroccan Dirham</b> currency.
	 */
	MOROCCAN_DIRHAM("MAD", "Moroccan Dirham", 2),

	/**
	 * International key, to use for localization, for <b>Mozambique Metical</b> currency.
	 */
	MOZAMBIQUE_METICAL("MZN", "Mozambique Metical", 2),

	/**
	 * International key, to use for localization, for <b>Mvdol</b> currency.
	 */
	MVDOL("BOV", "Mvdol", 2),

	/**
	 * International key, to use for localization, for <b>Naira</b> currency.
	 */
	NAIRA("NGN", "Naira", 2),

	/**
	 * International key, to use for localization, for <b>Nakfa</b> currency.
	 */
	NAKFA("ERN", "Nakfa", 2),

	/**
	 * International key, to use for localization, for <b>Namibia Dollar</b> currency.
	 */
	NAMIBIA_DOLLAR("NAD", "Namibia Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Nepalese Rupee</b> currency.
	 */
	NEPALESE_RUPEE("NPR", "Nepalese Rupee", 2),

	/**
	 * International key, to use for localization, for <b>Netherlands Antillean Guilder</b> currency.
	 */
	NETHERLANDS_ANTILLEAN_GUILDER("ANG", "Netherlands Antillean Guilder", 2),

	/**
	 * International key, to use for localization, for <b>New Israeli Sheqel</b> currency.
	 */
	NEW_ISRAELI_SHEQEL("ILS", "New Israeli Sheqel", 2),

	/**
	 * International key, to use for localization, for <b>New Taiwan Dollar</b> currency.
	 */
	NEW_TAIWAN_DOLLAR("TWD", "New Taiwan Dollar", 2),

	/**
	 * International key, to use for localization, for <b>New Zealand Dollar</b> currency.
	 */
	NEW_ZEALAND_DOLLAR("NZD", "New Zealand Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Ngultrum</b> currency.
	 */
	NGULTRUM("BTN", "Ngultrum", 2),

	/**
	 * International key, to use for localization, for <b>North Korean Won</b> currency.
	 */
	NORTH_KOREAN_WON("KPW", "North Korean Won", 2),

	/**
	 * International key, to use for localization, for <b>Norwegian Krone</b> currency.
	 */
	NORWEGIAN_KRONE("NOK", "Norwegian Krone", 2),

	/**
	 * International key, to use for localization, for <b>Ouguiya</b> currency.
	 */
	OUGUIYA("MRU", "Ouguiya", 2),

	/**
	 * International key, to use for localization, for <b>Pakistan Rupee</b> currency.
	 */
	PAKISTAN_RUPEE("PKR", "Pakistan Rupee", 2),

	/**
	 * International key, to use for localization, for <b>Palladium</b> currency.
	 */
	PALLADIUM("XPD", "Palladium", 2),

	/**
	 * International key, to use for localization, for <b>Pataca</b> currency.
	 */
	PATACA("MOP", "Pataca", 2),

	/**
	 * International key, to use for localization, for <b>Pa’anga</b> currency.
	 */
	PAANGA("TOP", "Pa’anga", 2),

	/**
	 * International key, to use for localization, for <b>Peso Convertible</b> currency.
	 */
	PESO_CONVERTIBLE("CUC", "Peso Convertible", 2),

	/**
	 * International key, to use for localization, for <b>Peso Uruguayo</b> currency.
	 */
	PESO_URUGUAYO("UYU", "Peso Uruguayo", 2),

	/**
	 * International key, to use for localization, for <b>Philippine Peso</b> currency.
	 */
	PHILIPPINE_PESO("PHP", "Philippine Peso", 2),

	/**
	 * International key, to use for localization, for <b>Platinum</b> currency.
	 */
	PLATINUM("XPT", "Platinum", 2),

	/**
	 * International key, to use for localization, for <b>Pound Sterling</b> currency.
	 */
	POUND_STERLING("GBP", "Pound Sterling", 2),

	/**
	 * International key, to use for localization, for <b>Pula</b> currency.
	 */
	PULA("BWP", "Pula", 2),

	/**
	 * International key, to use for localization, for <b>Qatari Rial</b> currency.
	 */
	QATARI_RIAL("QAR", "Qatari Rial", 2),

	/**
	 * International key, to use for localization, for <b>Quetzal</b> currency.
	 */
	QUETZAL("GTQ", "Quetzal", 2),

	/**
	 * International key, to use for localization, for <b>Rand</b> currency.
	 */
	RAND("ZAR", "Rand", 2),

	/**
	 * International key, to use for localization, for <b>Rial Omani</b> currency.
	 */
	RIAL_OMANI("OMR", "Rial Omani", 3),

	/**
	 * International key, to use for localization, for <b>Riel</b> currency.
	 */
	RIEL("KHR", "Riel", 2),

	/**
	 * International key, to use for localization, for <b>Romanian Leu</b> currency.
	 */
	ROMANIAN_LEU("RON", "Romanian Leu", 2),

	/**
	 * International key, to use for localization, for <b>Rufiyaa</b> currency.
	 */
	RUFIYAA("MVR", "Rufiyaa", 2),

	/**
	 * International key, to use for localization, for <b>Rupiah</b> currency.
	 */
	RUPIAH("IDR", "Rupiah", 2),

	/**
	 * International key, to use for localization, for <b>Russian Ruble</b> currency.
	 */
	RUSSIAN_RUBLE("RUB", "Russian Ruble", 2),

	/**
	 * International key, to use for localization, for <b>Rwanda Franc</b> currency.
	 */
	RWANDA_FRANC("RWF", "Rwanda Franc", 0),

	/**
	 * International key, to use for localization, for <b>SDR (Special Drawing Right)</b> currency.
	 */
	SPECIAL_DRAWING_RIGHT("XDR", "SDR (Special Drawing Right)", 2),

	/**
	 * International key, to use for localization, for <b>Saudi Riyal</b> currency.
	 */
	SAUDI_RIYAL("SAR", "Saudi Riyal", 2),

	/**
	 * International key, to use for localization, for <b>Serbian Dinar</b> currency.
	 */
	SERBIAN_DINAR("RSD", "Serbian Dinar", 2),

	/**
	 * International key, to use for localization, for <b>Seychelles Rupee</b> currency.
	 */
	SEYCHELLES_RUPEE("SCR", "Seychelles Rupee", 2),

	/**
	 * International key, to use for localization, for <b>Silver</b> currency.
	 */
	SILVER("XAG", "Silver", 2),

	/**
	 * International key, to use for localization, for <b>Singapore Dollar</b> currency.
	 */
	SINGAPORE_DOLLAR("SGD", "Singapore Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Sol</b> currency.
	 */
	SOL("PEN", "Sol", 2),

	/**
	 * International key, to use for localization, for <b>Solomon Islands Dollar</b> currency.
	 */
	SOLOMON_ISLANDS_DOLLAR("SBD", "Solomon Islands Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Som</b> currency.
	 */
	SOM("KGS", "Som", 2),

	/**
	 * International key, to use for localization, for <b>Somali Shilling</b> currency.
	 */
	SOMALI_SHILLING("SOS", "Somali Shilling", 2),

	/**
	 * International key, to use for localization, for <b>Somoni</b> currency.
	 */
	SOMONI("TJS", "Somoni", 2),

	/**
	 * International key, to use for localization, for <b>South Sudanese Pound</b> currency.
	 */
	SOUTH_SUDANESE_POUND("SSP", "South Sudanese Pound", 2),

	/**
	 * International key, to use for localization, for <b>Sri Lanka Rupee</b> currency.
	 */
	SRI_LANKA_RUPEE("LKR", "Sri Lanka Rupee", 2),

	/**
	 * International key, to use for localization, for <b>Sucre</b> currency.
	 */
	SUCRE("XSU", "Sucre", 2),

	/**
	 * International key, to use for localization, for <b>Sudanese Pound</b> currency.
	 */
	SUDANESE_POUND("SDG", "Sudanese Pound", 2),

	/**
	 * International key, to use for localization, for <b>Surinam Dollar</b> currency.
	 */
	SURINAM_DOLLAR("SRD", "Surinam Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Swedish Krona</b> currency.
	 */
	SWEDISH_KRONA("SEK", "Swedish Krona", 2),

	/**
	 * International key, to use for localization, for <b>Swiss Franc</b> currency.
	 */
	SWISS_FRANC("CHF", "Swiss Franc", 2),

	/**
	 * International key, to use for localization, for <b>Syrian Pound</b> currency.
	 */
	SYRIAN_POUND("SYP", "Syrian Pound", 2),

	/**
	 * International key, to use for localization, for <b>Taka</b> currency.
	 */
	TAKA("BDT", "Taka", 2),

	/**
	 * International key, to use for localization, for <b>Tala</b> currency.
	 */
	TALA("WST", "Tala", 2),

	/**
	 * International key, to use for localization, for <b>Tenge</b> currency.
	 */
	TENGE("KZT", "Tenge", 2),

	/**
	 * International key, to use for localization, for <b>The codes assigned for transactions where no currency is involved</b> currency.
	 */
	THE_CODES_ASSIGNED_FOR_TRANSACTIONS_WHERE_NO_CURRENCY_IS_INVOLVED("XXX", "The codes assigned for transactions where no currency is involved", 2),

	/**
	 * International key, to use for localization, for <b>Trinidad and Tobago Dollar</b> currency.
	 */
	TRINIDAD_AND_TOBAGO_DOLLAR("TTD", "Trinidad and Tobago Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Tugrik</b> currency.
	 */
	TUGRIK("MNT", "Tugrik", 2),

	/**
	 * International key, to use for localization, for <b>Tunisian Dinar</b> currency.
	 */
	TUNISIAN_DINAR("TND", "Tunisian Dinar", 3),

	/**
	 * International key, to use for localization, for <b>Turkish Lira</b> currency.
	 */
	TURKISH_LIRA("TRY", "Turkish Lira", 2),

	/**
	 * International key, to use for localization, for <b>Turkmenistan New Manat</b> currency.
	 */
	TURKMENISTAN_NEW_MANAT("TMT", "Turkmenistan New Manat", 2),

	/**
	 * International key, to use for localization, for <b>UAE Dirham</b> currency.
	 */
	UAE_DIRHAM("AED", "UAE Dirham", 2),

	/**
	 * International key, to use for localization, for <b>US Dollar</b> currency.
	 */
	US_DOLLAR("USD", "US Dollar", 2),

	/**
	 * International key, to use for localization, for <b>US Dollar (Next day)</b> currency.
	 */
	US_DOLLAR_NEXT_DAY("USN", "US Dollar (Next day)", 2),

	/**
	 * International key, to use for localization, for <b>Uganda Shilling</b> currency.
	 */
	UGANDA_SHILLING("UGX", "Uganda Shilling", 0),

	/**
	 * International key, to use for localization, for <b>Unidad Previsional</b> currency.
	 */
	UNIDAD_PREVISIONAL("UYW", "Unidad Previsional", 4),

	/**
	 * International key, to use for localization, for <b>Unidad de Fomento</b> currency.
	 */
	UNIDAD_DE_FOMENTO("CLF", "Unidad de Fomento", 4),

	/**
	 * International key, to use for localization, for <b>Unidad de Valor Real</b> currency.
	 */
	UNIDAD_DE_VALOR_REAL("COU", "Unidad de Valor Real", 2),

	/**
	 * International key, to use for localization, for <b>Uruguay Peso en Unidades Indexadas (UI)</b> currency.
	 */
	URUGUAY_PESO_EN_UNIDADES_INDEXADAS("UYI", "Uruguay Peso en Unidades Indexadas (UI)", 0),

	/**
	 * International key, to use for localization, for <b>Uzbekistan Sum</b> currency.
	 */
	UZBEKISTAN_SUM("UZS", "Uzbekistan Sum", 2),

	/**
	 * International key, to use for localization, for <b>Vatu</b> currency.
	 */
	VATU("VUV", "Vatu", 0),

	/**
	 * International key, to use for localization, for <b>WIR Euro</b> currency.
	 */
	WIR_EURO("CHE", "WIR Euro", 2),

	/**
	 * International key, to use for localization, for <b>WIR Franc</b> currency.
	 */
	WIR_FRANC("CHW", "WIR Franc", 2),

	/**
	 * International key, to use for localization, for <b>Won</b> currency.
	 */
	WON("KRW", "Won", 0),

	/**
	 * International key, to use for localization, for <b>Yemeni Rial</b> currency.
	 */
	YEMENI_RIAL("YER", "Yemeni Rial", 2),

	/**
	 * International key, to use for localization, for <b>Yen</b> currency.
	 */
	YEN("JPY", "Yen", 0),

	/**
	 * International key, to use for localization, for <b>Yuan Renminbi</b> currency.
	 */
	YUAN_RENMINBI("CNY", "Yuan Renminbi", 2),

	/**
	 * International key, to use for localization, for <b>Zambian Kwacha</b> currency.
	 */
	ZAMBIAN_KWACHA("ZMW", "Zambian Kwacha", 2),

	/**
	 * International key, to use for localization, for <b>Zimbabwe Dollar</b> currency.
	 */
	ZIMBABWE_DOLLAR("ZWL", "Zimbabwe Dollar", 2),

	/**
	 * International key, to use for localization, for <b>Zloty</b> currency.
	 */
	ZLOTY("PLN", "Zloty", 2);

	// value for key
	private final String value;
	// name of region
	private final String name;
	// minimum fraction digits
	private final int minimumFractionDigits;

	/**
	 * Creates the object with currency value and its name.
	 * 
	 * @param value currency identifier
	 * @param name name of the region
	 * @param minimumFractionDigits minimum number of fraction digits to use
	 */
	private Currency(String value, String name, int minimumFractionDigits) {
		this.value = value;
		this.name = name;
		this.minimumFractionDigits = minimumFractionDigits;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.commons.Key#value()
	 */
	@Override
	public String value() {
		return value;
	}

	/**
	 * Returns the name of the currency.
	 * 
	 * @return the name of the currency
	 */
	@Override
	public String getName() {
		return name;
	}

	/**
	 * Returns the minimum number of fraction digits to use.
	 * 
	 * @return the minimum number of fraction digits to use
	 */
	public int getMinimumFractionDigits() {
		return minimumFractionDigits;
	}

}