/**
    Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at
    
      http://www.apache.org/licenses/LICENSE-2.0
    
    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.pepstock.charba.client.intl.enums;

import org.pepstock.charba.client.commons.Key;

/**
 * Enumerates the time zones identifiers which can be used on dates management.<br>
 * See <a href="https://en.wikipedia.org/wiki/List_of_tz_database_time_zones">IANA times zones</a> for more details.
 * 
 * @author Andrea "Stock" Stocchero
 */
public enum TimeZone implements Key
{
	/**
	 * International key, to use for localization, for <b>Africa/Abidjan</b> timezone.
	 */
	AFRICA_ABIDJAN("Africa/Abidjan", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Accra</b> timezone.
	 */
	AFRICA_ACCRA("Africa/Accra", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Addis_Ababa</b> timezone.
	 */
	AFRICA_ADDIS_ABABA("Africa/Addis_Ababa", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Algiers</b> timezone.
	 */
	AFRICA_ALGIERS("Africa/Algiers", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Asmara</b> timezone.
	 */
	AFRICA_ASMARA("Africa/Asmara", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Asmera</b> timezone.
	 */
	AFRICA_ASMERA("Africa/Asmera", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Bamako</b> timezone.
	 */
	AFRICA_BAMAKO("Africa/Bamako", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Bangui</b> timezone.
	 */
	AFRICA_BANGUI("Africa/Bangui", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Banjul</b> timezone.
	 */
	AFRICA_BANJUL("Africa/Banjul", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Blantyre</b> timezone.
	 */
	AFRICA_BLANTYRE("Africa/Blantyre", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Brazzaville</b> timezone.
	 */
	AFRICA_BRAZZAVILLE("Africa/Brazzaville", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Bujumbura</b> timezone.
	 */
	AFRICA_BUJUMBURA("Africa/Bujumbura", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Cairo</b> timezone.
	 */
	AFRICA_CAIRO("Africa/Cairo", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Casablanca</b> timezone.
	 */
	AFRICA_CASABLANCA("Africa/Casablanca", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Ceuta</b> timezone.
	 */
	AFRICA_CEUTA("Africa/Ceuta", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Conakry</b> timezone.
	 */
	AFRICA_CONAKRY("Africa/Conakry", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Dakar</b> timezone.
	 */
	AFRICA_DAKAR("Africa/Dakar", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Dar_es_Salaam</b> timezone.
	 */
	AFRICA_DAR_ES_SALAAM("Africa/Dar_es_Salaam", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Djibouti</b> timezone.
	 */
	AFRICA_DJIBOUTI("Africa/Djibouti", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Douala</b> timezone.
	 */
	AFRICA_DOUALA("Africa/Douala", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/El_Aaiun</b> timezone.
	 */
	AFRICA_EL_AAIUN("Africa/El_Aaiun", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Freetown</b> timezone.
	 */
	AFRICA_FREETOWN("Africa/Freetown", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Gaborone</b> timezone.
	 */
	AFRICA_GABORONE("Africa/Gaborone", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Harare</b> timezone.
	 */
	AFRICA_HARARE("Africa/Harare", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Johannesburg</b> timezone.
	 */
	AFRICA_JOHANNESBURG("Africa/Johannesburg", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Juba</b> timezone.
	 */
	AFRICA_JUBA("Africa/Juba", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Kampala</b> timezone.
	 */
	AFRICA_KAMPALA("Africa/Kampala", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Khartoum</b> timezone.
	 */
	AFRICA_KHARTOUM("Africa/Khartoum", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Kigali</b> timezone.
	 */
	AFRICA_KIGALI("Africa/Kigali", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Kinshasa</b> timezone.
	 */
	AFRICA_KINSHASA("Africa/Kinshasa", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Lagos</b> timezone.
	 */
	AFRICA_LAGOS("Africa/Lagos", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Libreville</b> timezone.
	 */
	AFRICA_LIBREVILLE("Africa/Libreville", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Lome</b> timezone.
	 */
	AFRICA_LOME("Africa/Lome", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Luanda</b> timezone.
	 */
	AFRICA_LUANDA("Africa/Luanda", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Lubumbashi</b> timezone.
	 */
	AFRICA_LUBUMBASHI("Africa/Lubumbashi", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Lusaka</b> timezone.
	 */
	AFRICA_LUSAKA("Africa/Lusaka", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Malabo</b> timezone.
	 */
	AFRICA_MALABO("Africa/Malabo", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Maputo</b> timezone.
	 */
	AFRICA_MAPUTO("Africa/Maputo", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Maseru</b> timezone.
	 */
	AFRICA_MASERU("Africa/Maseru", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Mbabane</b> timezone.
	 */
	AFRICA_MBABANE("Africa/Mbabane", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Mogadishu</b> timezone.
	 */
	AFRICA_MOGADISHU("Africa/Mogadishu", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Monrovia</b> timezone.
	 */
	AFRICA_MONROVIA("Africa/Monrovia", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Nairobi</b> timezone.
	 */
	AFRICA_NAIROBI("Africa/Nairobi", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Africa/Ndjamena</b> timezone.
	 */
	AFRICA_NDJAMENA("Africa/Ndjamena", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Niamey</b> timezone.
	 */
	AFRICA_NIAMEY("Africa/Niamey", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Nouakchott</b> timezone.
	 */
	AFRICA_NOUAKCHOTT("Africa/Nouakchott", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Ouagadougou</b> timezone.
	 */
	AFRICA_OUAGADOUGOU("Africa/Ouagadougou", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Porto-Novo</b> timezone.
	 */
	AFRICA_PORTO_NOVO("Africa/Porto-Novo", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Sao_Tome</b> timezone.
	 */
	AFRICA_SAO_TOME("Africa/Sao_Tome", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Timbuktu</b> timezone.
	 */
	AFRICA_TIMBUKTU("Africa/Timbuktu", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Africa/Tripoli</b> timezone.
	 */
	AFRICA_TRIPOLI("Africa/Tripoli", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Africa/Tunis</b> timezone.
	 */
	AFRICA_TUNIS("Africa/Tunis", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Africa/Windhoek</b> timezone.
	 */
	AFRICA_WINDHOEK("Africa/Windhoek", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>America/Adak</b> timezone.
	 */
	AMERICA_ADAK("America/Adak", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>America/Anchorage</b> timezone.
	 */
	AMERICA_ANCHORAGE("America/Anchorage", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>America/Anguilla</b> timezone.
	 */
	AMERICA_ANGUILLA("America/Anguilla", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Antigua</b> timezone.
	 */
	AMERICA_ANTIGUA("America/Antigua", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Araguaina</b> timezone.
	 */
	AMERICA_ARAGUAINA("America/Araguaina", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Buenos_Aires</b> timezone.
	 */
	AMERICA_ARGENTINA_BUENOS_AIRES("America/Argentina/Buenos_Aires", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Catamarca</b> timezone.
	 */
	AMERICA_ARGENTINA_CATAMARCA("America/Argentina/Catamarca", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/ComodRivadavia</b> timezone.
	 */
	AMERICA_ARGENTINA_COMODRIVADAVIA("America/Argentina/ComodRivadavia", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Cordoba</b> timezone.
	 */
	AMERICA_ARGENTINA_CORDOBA("America/Argentina/Cordoba", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Jujuy</b> timezone.
	 */
	AMERICA_ARGENTINA_JUJUY("America/Argentina/Jujuy", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/La_Rioja</b> timezone.
	 */
	AMERICA_ARGENTINA_LA_RIOJA("America/Argentina/La_Rioja", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Mendoza</b> timezone.
	 */
	AMERICA_ARGENTINA_MENDOZA("America/Argentina/Mendoza", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Rio_Gallegos</b> timezone.
	 */
	AMERICA_ARGENTINA_RIO_GALLEGOS("America/Argentina/Rio_Gallegos", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Salta</b> timezone.
	 */
	AMERICA_ARGENTINA_SALTA("America/Argentina/Salta", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/San_Juan</b> timezone.
	 */
	AMERICA_ARGENTINA_SAN_JUAN("America/Argentina/San_Juan", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/San_Luis</b> timezone.
	 */
	AMERICA_ARGENTINA_SAN_LUIS("America/Argentina/San_Luis", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Tucuman</b> timezone.
	 */
	AMERICA_ARGENTINA_TUCUMAN("America/Argentina/Tucuman", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Argentina/Ushuaia</b> timezone.
	 */
	AMERICA_ARGENTINA_USHUAIA("America/Argentina/Ushuaia", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Aruba</b> timezone.
	 */
	AMERICA_ARUBA("America/Aruba", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Asuncion</b> timezone.
	 */
	AMERICA_ASUNCION("America/Asuncion", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Atikokan</b> timezone.
	 */
	AMERICA_ATIKOKAN("America/Atikokan", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Atka</b> timezone.
	 */
	AMERICA_ATKA("America/Atka", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>America/Bahia</b> timezone.
	 */
	AMERICA_BAHIA("America/Bahia", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Bahia_Banderas</b> timezone.
	 */
	AMERICA_BAHIA_BANDERAS("America/Bahia_Banderas", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Barbados</b> timezone.
	 */
	AMERICA_BARBADOS("America/Barbados", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Belem</b> timezone.
	 */
	AMERICA_BELEM("America/Belem", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Belize</b> timezone.
	 */
	AMERICA_BELIZE("America/Belize", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Blanc-Sablon</b> timezone.
	 */
	AMERICA_BLANC_SABLON("America/Blanc-Sablon", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Boa_Vista</b> timezone.
	 */
	AMERICA_BOA_VISTA("America/Boa_Vista", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Bogota</b> timezone.
	 */
	AMERICA_BOGOTA("America/Bogota", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Boise</b> timezone.
	 */
	AMERICA_BOISE("America/Boise", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Buenos_Aires</b> timezone.
	 */
	AMERICA_BUENOS_AIRES("America/Buenos_Aires", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Cambridge_Bay</b> timezone.
	 */
	AMERICA_CAMBRIDGE_BAY("America/Cambridge_Bay", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Campo_Grande</b> timezone.
	 */
	AMERICA_CAMPO_GRANDE("America/Campo_Grande", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Cancun</b> timezone.
	 */
	AMERICA_CANCUN("America/Cancun", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Caracas</b> timezone.
	 */
	AMERICA_CARACAS("America/Caracas", UTCOffsetConstants.UTC_MINUS_04_30),

	/**
	 * International key, to use for localization, for <b>America/Catamarca</b> timezone.
	 */
	AMERICA_CATAMARCA("America/Catamarca", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Cayenne</b> timezone.
	 */
	AMERICA_CAYENNE("America/Cayenne", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Cayman</b> timezone.
	 */
	AMERICA_CAYMAN("America/Cayman", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Chicago</b> timezone.
	 */
	AMERICA_CHICAGO("America/Chicago", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Chihuahua</b> timezone.
	 */
	AMERICA_CHIHUAHUA("America/Chihuahua", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Coral_Harbour</b> timezone.
	 */
	AMERICA_CORAL_HARBOUR("America/Coral_Harbour", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Cordoba</b> timezone.
	 */
	AMERICA_CORDOBA("America/Cordoba", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Costa_Rica</b> timezone.
	 */
	AMERICA_COSTA_RICA("America/Costa_Rica", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Creston</b> timezone.
	 */
	AMERICA_CRESTON("America/Creston", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Cuiaba</b> timezone.
	 */
	AMERICA_CUIABA("America/Cuiaba", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Curacao</b> timezone.
	 */
	AMERICA_CURACAO("America/Curacao", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Danmarkshavn</b> timezone.
	 */
	AMERICA_DANMARKSHAVN("America/Danmarkshavn", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>America/Dawson</b> timezone.
	 */
	AMERICA_DAWSON("America/Dawson", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Dawson_Creek</b> timezone.
	 */
	AMERICA_DAWSON_CREEK("America/Dawson_Creek", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Denver</b> timezone.
	 */
	AMERICA_DENVER("America/Denver", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Detroit</b> timezone.
	 */
	AMERICA_DETROIT("America/Detroit", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Dominica</b> timezone.
	 */
	AMERICA_DOMINICA("America/Dominica", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Edmonton</b> timezone.
	 */
	AMERICA_EDMONTON("America/Edmonton", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Eirunepe</b> timezone.
	 */
	AMERICA_EIRUNEPE("America/Eirunepe", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/El_Salvador</b> timezone.
	 */
	AMERICA_EL_SALVADOR("America/El_Salvador", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Ensenada</b> timezone.
	 */
	AMERICA_ENSENADA("America/Ensenada", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Fort_Wayne</b> timezone.
	 */
	AMERICA_FORT_WAYNE("America/Fort_Wayne", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Fortaleza</b> timezone.
	 */
	AMERICA_FORTALEZA("America/Fortaleza", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Glace_Bay</b> timezone.
	 */
	AMERICA_GLACE_BAY("America/Glace_Bay", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Godthab</b> timezone.
	 */
	AMERICA_GODTHAB("America/Godthab", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Goose_Bay</b> timezone.
	 */
	AMERICA_GOOSE_BAY("America/Goose_Bay", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Grand_Turk</b> timezone.
	 */
	AMERICA_GRAND_TURK("America/Grand_Turk", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Grenada</b> timezone.
	 */
	AMERICA_GRENADA("America/Grenada", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Guadeloupe</b> timezone.
	 */
	AMERICA_GUADELOUPE("America/Guadeloupe", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Guatemala</b> timezone.
	 */
	AMERICA_GUATEMALA("America/Guatemala", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Guayaquil</b> timezone.
	 */
	AMERICA_GUAYAQUIL("America/Guayaquil", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Guyana</b> timezone.
	 */
	AMERICA_GUYANA("America/Guyana", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Halifax</b> timezone.
	 */
	AMERICA_HALIFAX("America/Halifax", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Havana</b> timezone.
	 */
	AMERICA_HAVANA("America/Havana", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Hermosillo</b> timezone.
	 */
	AMERICA_HERMOSILLO("America/Hermosillo", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Indianapolis</b> timezone.
	 */
	AMERICA_INDIANA_INDIANAPOLIS("America/Indiana/Indianapolis", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Knox</b> timezone.
	 */
	AMERICA_INDIANA_KNOX("America/Indiana/Knox", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Marengo</b> timezone.
	 */
	AMERICA_INDIANA_MARENGO("America/Indiana/Marengo", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Petersburg</b> timezone.
	 */
	AMERICA_INDIANA_PETERSBURG("America/Indiana/Petersburg", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Tell_City</b> timezone.
	 */
	AMERICA_INDIANA_TELL_CITY("America/Indiana/Tell_City", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Valparaiso</b> timezone.
	 */
	AMERICA_INDIANA_VALPARAISO("America/Indiana/Valparaiso", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Vevay</b> timezone.
	 */
	AMERICA_INDIANA_VEVAY("America/Indiana/Vevay", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Vincennes</b> timezone.
	 */
	AMERICA_INDIANA_VINCENNES("America/Indiana/Vincennes", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Indiana/Winamac</b> timezone.
	 */
	AMERICA_INDIANA_WINAMAC("America/Indiana/Winamac", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Indianapolis</b> timezone.
	 */
	AMERICA_INDIANAPOLIS("America/Indianapolis", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Inuvik</b> timezone.
	 */
	AMERICA_INUVIK("America/Inuvik", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Iqaluit</b> timezone.
	 */
	AMERICA_IQALUIT("America/Iqaluit", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Jamaica</b> timezone.
	 */
	AMERICA_JAMAICA("America/Jamaica", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Jujuy</b> timezone.
	 */
	AMERICA_JUJUY("America/Jujuy", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Juneau</b> timezone.
	 */
	AMERICA_JUNEAU("America/Juneau", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>America/Kentucky/Louisville</b> timezone.
	 */
	AMERICA_KENTUCKY_LOUISVILLE("America/Kentucky/Louisville", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Kentucky/Monticello</b> timezone.
	 */
	AMERICA_KENTUCKY_MONTICELLO("America/Kentucky/Monticello", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Knox_IN</b> timezone.
	 */
	AMERICA_KNOX_IN("America/Knox_IN", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Kralendijk</b> timezone.
	 */
	AMERICA_KRALENDIJK("America/Kralendijk", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/La_Paz</b> timezone.
	 */
	AMERICA_LA_PAZ("America/La_Paz", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Lima</b> timezone.
	 */
	AMERICA_LIMA("America/Lima", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Los_Angeles</b> timezone.
	 */
	AMERICA_LOS_ANGELES("America/Los_Angeles", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Louisville</b> timezone.
	 */
	AMERICA_LOUISVILLE("America/Louisville", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Lower_Princes</b> timezone.
	 */
	AMERICA_LOWER_PRINCES("America/Lower_Princes", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Maceio</b> timezone.
	 */
	AMERICA_MACEIO("America/Maceio", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Managua</b> timezone.
	 */
	AMERICA_MANAGUA("America/Managua", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Manaus</b> timezone.
	 */
	AMERICA_MANAUS("America/Manaus", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Marigot</b> timezone.
	 */
	AMERICA_MARIGOT("America/Marigot", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Martinique</b> timezone.
	 */
	AMERICA_MARTINIQUE("America/Martinique", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Matamoros</b> timezone.
	 */
	AMERICA_MATAMOROS("America/Matamoros", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Mazatlan</b> timezone.
	 */
	AMERICA_MAZATLAN("America/Mazatlan", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Mendoza</b> timezone.
	 */
	AMERICA_MENDOZA("America/Mendoza", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Menominee</b> timezone.
	 */
	AMERICA_MENOMINEE("America/Menominee", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Merida</b> timezone.
	 */
	AMERICA_MERIDA("America/Merida", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Metlakatla</b> timezone.
	 */
	AMERICA_METLAKATLA("America/Metlakatla", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Mexico_City</b> timezone.
	 */
	AMERICA_MEXICO_CITY("America/Mexico_City", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Miquelon</b> timezone.
	 */
	AMERICA_MIQUELON("America/Miquelon", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Moncton</b> timezone.
	 */
	AMERICA_MONCTON("America/Moncton", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Monterrey</b> timezone.
	 */
	AMERICA_MONTERREY("America/Monterrey", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Montevideo</b> timezone.
	 */
	AMERICA_MONTEVIDEO("America/Montevideo", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Montreal</b> timezone.
	 */
	AMERICA_MONTREAL("America/Montreal", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Montserrat</b> timezone.
	 */
	AMERICA_MONTSERRAT("America/Montserrat", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Nassau</b> timezone.
	 */
	AMERICA_NASSAU("America/Nassau", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/New_York</b> timezone.
	 */
	AMERICA_NEW_YORK("America/New_York", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Nipigon</b> timezone.
	 */
	AMERICA_NIPIGON("America/Nipigon", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Nome</b> timezone.
	 */
	AMERICA_NOME("America/Nome", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>America/Noronha</b> timezone.
	 */
	AMERICA_NORONHA("America/Noronha", UTCOffsetConstants.UTC_MINUS_02_00),

	/**
	 * International key, to use for localization, for <b>America/North_Dakota/Beulah</b> timezone.
	 */
	AMERICA_NORTH_DAKOTA_BEULAH("America/North_Dakota/Beulah", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/North_Dakota/Center</b> timezone.
	 */
	AMERICA_NORTH_DAKOTA_CENTER("America/North_Dakota/Center", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/North_Dakota/New_Salem</b> timezone.
	 */
	AMERICA_NORTH_DAKOTA_NEW_SALEM("America/North_Dakota/New_Salem", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Ojinaga</b> timezone.
	 */
	AMERICA_OJINAGA("America/Ojinaga", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Panama</b> timezone.
	 */
	AMERICA_PANAMA("America/Panama", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Pangnirtung</b> timezone.
	 */
	AMERICA_PANGNIRTUNG("America/Pangnirtung", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Paramaribo</b> timezone.
	 */
	AMERICA_PARAMARIBO("America/Paramaribo", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Phoenix</b> timezone.
	 */
	AMERICA_PHOENIX("America/Phoenix", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Port-au-Prince</b> timezone.
	 */
	AMERICA_PORT_AU_PRINCE("America/Port-au-Prince", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Port_of_Spain</b> timezone.
	 */
	AMERICA_PORT_OF_SPAIN("America/Port_of_Spain", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Porto_Acre</b> timezone.
	 */
	AMERICA_PORTO_ACRE("America/Porto_Acre", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Porto_Velho</b> timezone.
	 */
	AMERICA_PORTO_VELHO("America/Porto_Velho", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Puerto_Rico</b> timezone.
	 */
	AMERICA_PUERTO_RICO("America/Puerto_Rico", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Rainy_River</b> timezone.
	 */
	AMERICA_RAINY_RIVER("America/Rainy_River", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Rankin_Inlet</b> timezone.
	 */
	AMERICA_RANKIN_INLET("America/Rankin_Inlet", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Recife</b> timezone.
	 */
	AMERICA_RECIFE("America/Recife", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Regina</b> timezone.
	 */
	AMERICA_REGINA("America/Regina", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Resolute</b> timezone.
	 */
	AMERICA_RESOLUTE("America/Resolute", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Rio_Branco</b> timezone.
	 */
	AMERICA_RIO_BRANCO("America/Rio_Branco", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Rosario</b> timezone.
	 */
	AMERICA_ROSARIO("America/Rosario", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Santa_Isabel</b> timezone.
	 */
	AMERICA_SANTA_ISABEL("America/Santa_Isabel", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Santarem</b> timezone.
	 */
	AMERICA_SANTAREM("America/Santarem", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Santiago</b> timezone.
	 */
	AMERICA_SANTIAGO("America/Santiago", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Santo_Domingo</b> timezone.
	 */
	AMERICA_SANTO_DOMINGO("America/Santo_Domingo", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Sao_Paulo</b> timezone.
	 */
	AMERICA_SAO_PAULO("America/Sao_Paulo", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>America/Scoresbysund</b> timezone.
	 */
	AMERICA_SCORESBYSUND("America/Scoresbysund", UTCOffsetConstants.UTC_MINUS_01_00),

	/**
	 * International key, to use for localization, for <b>America/Shiprock</b> timezone.
	 */
	AMERICA_SHIPROCK("America/Shiprock", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>America/Sitka</b> timezone.
	 */
	AMERICA_SITKA("America/Sitka", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>America/St_Barthelemy</b> timezone.
	 */
	AMERICA_ST_BARTHELEMY("America/St_Barthelemy", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/St_Johns</b> timezone.
	 */
	AMERICA_ST_JOHNS("America/St_Johns", UTCOffsetConstants.UTC_MINUS_03_30),

	/**
	 * International key, to use for localization, for <b>America/St_Kitts</b> timezone.
	 */
	AMERICA_ST_KITTS("America/St_Kitts", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/St_Lucia</b> timezone.
	 */
	AMERICA_ST_LUCIA("America/St_Lucia", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/St_Thomas</b> timezone.
	 */
	AMERICA_ST_THOMAS("America/St_Thomas", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/St_Vincent</b> timezone.
	 */
	AMERICA_ST_VINCENT("America/St_Vincent", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Swift_Current</b> timezone.
	 */
	AMERICA_SWIFT_CURRENT("America/Swift_Current", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Tegucigalpa</b> timezone.
	 */
	AMERICA_TEGUCIGALPA("America/Tegucigalpa", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Thule</b> timezone.
	 */
	AMERICA_THULE("America/Thule", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Thunder_Bay</b> timezone.
	 */
	AMERICA_THUNDER_BAY("America/Thunder_Bay", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Tijuana</b> timezone.
	 */
	AMERICA_TIJUANA("America/Tijuana", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Toronto</b> timezone.
	 */
	AMERICA_TORONTO("America/Toronto", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>America/Tortola</b> timezone.
	 */
	AMERICA_TORTOLA("America/Tortola", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Vancouver</b> timezone.
	 */
	AMERICA_VANCOUVER("America/Vancouver", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Virgin</b> timezone.
	 */
	AMERICA_VIRGIN("America/Virgin", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>America/Whitehorse</b> timezone.
	 */
	AMERICA_WHITEHORSE("America/Whitehorse", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>America/Winnipeg</b> timezone.
	 */
	AMERICA_WINNIPEG("America/Winnipeg", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>America/Yakutat</b> timezone.
	 */
	AMERICA_YAKUTAT("America/Yakutat", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>America/Yellowknife</b> timezone.
	 */
	AMERICA_YELLOWKNIFE("America/Yellowknife", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Casey</b> timezone.
	 */
	ANTARCTICA_CASEY("Antarctica/Casey", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Davis</b> timezone.
	 */
	ANTARCTICA_DAVIS("Antarctica/Davis", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/DumontDUrville</b> timezone.
	 */
	ANTARCTICA_DUMONTDURVILLE("Antarctica/DumontDUrville", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Macquarie</b> timezone.
	 */
	ANTARCTICA_MACQUARIE("Antarctica/Macquarie", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Mawson</b> timezone.
	 */
	ANTARCTICA_MAWSON("Antarctica/Mawson", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/McMurdo</b> timezone.
	 */
	ANTARCTICA_MCMURDO("Antarctica/McMurdo", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Palmer</b> timezone.
	 */
	ANTARCTICA_PALMER("Antarctica/Palmer", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Rothera</b> timezone.
	 */
	ANTARCTICA_ROTHERA("Antarctica/Rothera", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/South_Pole</b> timezone.
	 */
	ANTARCTICA_SOUTH_POLE("Antarctica/South_Pole", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Syowa</b> timezone.
	 */
	ANTARCTICA_SYOWA("Antarctica/Syowa", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Troll</b> timezone.
	 */
	ANTARCTICA_TROLL("Antarctica/Troll", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Antarctica/Vostok</b> timezone.
	 */
	ANTARCTICA_VOSTOK("Antarctica/Vostok", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Arctic/Longyearbyen</b> timezone.
	 */
	ARCTIC_LONGYEARBYEN("Arctic/Longyearbyen", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Asia/Aden</b> timezone.
	 */
	ASIA_ADEN("Asia/Aden", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Asia/Almaty</b> timezone.
	 */
	ASIA_ALMATY("Asia/Almaty", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Amman</b> timezone.
	 */
	ASIA_AMMAN("Asia/Amman", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Anadyr</b> timezone.
	 */
	ASIA_ANADYR("Asia/Anadyr", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Asia/Aqtau</b> timezone.
	 */
	ASIA_AQTAU("Asia/Aqtau", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Aqtobe</b> timezone.
	 */
	ASIA_AQTOBE("Asia/Aqtobe", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ashgabat</b> timezone.
	 */
	ASIA_ASHGABAT("Asia/Ashgabat", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ashkhabad</b> timezone.
	 */
	ASIA_ASHKHABAD("Asia/Ashkhabad", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Baghdad</b> timezone.
	 */
	ASIA_BAGHDAD("Asia/Baghdad", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Asia/Bahrain</b> timezone.
	 */
	ASIA_BAHRAIN("Asia/Bahrain", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Asia/Baku</b> timezone.
	 */
	ASIA_BAKU("Asia/Baku", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Asia/Bangkok</b> timezone.
	 */
	ASIA_BANGKOK("Asia/Bangkok", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Beirut</b> timezone.
	 */
	ASIA_BEIRUT("Asia/Beirut", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Bishkek</b> timezone.
	 */
	ASIA_BISHKEK("Asia/Bishkek", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Brunei</b> timezone.
	 */
	ASIA_BRUNEI("Asia/Brunei", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Calcutta</b> timezone.
	 */
	ASIA_CALCUTTA("Asia/Calcutta", UTCOffsetConstants.UTC_PLUS_05_30),

	/**
	 * International key, to use for localization, for <b>Asia/Choibalsan</b> timezone.
	 */
	ASIA_CHOIBALSAN("Asia/Choibalsan", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Chongqing</b> timezone.
	 */
	ASIA_CHONGQING("Asia/Chongqing", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Chungking</b> timezone.
	 */
	ASIA_CHUNGKING("Asia/Chungking", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Colombo</b> timezone.
	 */
	ASIA_COLOMBO("Asia/Colombo", UTCOffsetConstants.UTC_PLUS_05_30),

	/**
	 * International key, to use for localization, for <b>Asia/Dacca</b> timezone.
	 */
	ASIA_DACCA("Asia/Dacca", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Damascus</b> timezone.
	 */
	ASIA_DAMASCUS("Asia/Damascus", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Dhaka</b> timezone.
	 */
	ASIA_DHAKA("Asia/Dhaka", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Dili</b> timezone.
	 */
	ASIA_DILI("Asia/Dili", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Dubai</b> timezone.
	 */
	ASIA_DUBAI("Asia/Dubai", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Asia/Dushanbe</b> timezone.
	 */
	ASIA_DUSHANBE("Asia/Dushanbe", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Gaza</b> timezone.
	 */
	ASIA_GAZA("Asia/Gaza", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Harbin</b> timezone.
	 */
	ASIA_HARBIN("Asia/Harbin", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Hebron</b> timezone.
	 */
	ASIA_HEBRON("Asia/Hebron", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ho_Chi_Minh</b> timezone.
	 */
	ASIA_HO_CHI_MINH("Asia/Ho_Chi_Minh", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Hong_Kong</b> timezone.
	 */
	ASIA_HONG_KONG("Asia/Hong_Kong", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Hovd</b> timezone.
	 */
	ASIA_HOVD("Asia/Hovd", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Irkutsk</b> timezone.
	 */
	ASIA_IRKUTSK("Asia/Irkutsk", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Istanbul</b> timezone.
	 */
	ASIA_ISTANBUL("Asia/Istanbul", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Jakarta</b> timezone.
	 */
	ASIA_JAKARTA("Asia/Jakarta", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Jayapura</b> timezone.
	 */
	ASIA_JAYAPURA("Asia/Jayapura", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Jerusalem</b> timezone.
	 */
	ASIA_JERUSALEM("Asia/Jerusalem", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kabul</b> timezone.
	 */
	ASIA_KABUL("Asia/Kabul", UTCOffsetConstants.UTC_PLUS_04_30),

	/**
	 * International key, to use for localization, for <b>Asia/Kamchatka</b> timezone.
	 */
	ASIA_KAMCHATKA("Asia/Kamchatka", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Asia/Karachi</b> timezone.
	 */
	ASIA_KARACHI("Asia/Karachi", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kashgar</b> timezone.
	 */
	ASIA_KASHGAR("Asia/Kashgar", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kathmandu</b> timezone.
	 */
	ASIA_KATHMANDU("Asia/Kathmandu", UTCOffsetConstants.UTC_PLUS_05_45),

	/**
	 * International key, to use for localization, for <b>Asia/Katmandu</b> timezone.
	 */
	ASIA_KATMANDU("Asia/Katmandu", UTCOffsetConstants.UTC_PLUS_05_45),

	/**
	 * International key, to use for localization, for <b>Asia/Khandyga</b> timezone.
	 */
	ASIA_KHANDYGA("Asia/Khandyga", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kolkata</b> timezone.
	 */
	ASIA_KOLKATA("Asia/Kolkata", UTCOffsetConstants.UTC_PLUS_05_30),

	/**
	 * International key, to use for localization, for <b>Asia/Krasnoyarsk</b> timezone.
	 */
	ASIA_KRASNOYARSK("Asia/Krasnoyarsk", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kuala_Lumpur</b> timezone.
	 */
	ASIA_KUALA_LUMPUR("Asia/Kuala_Lumpur", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kuching</b> timezone.
	 */
	ASIA_KUCHING("Asia/Kuching", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Kuwait</b> timezone.
	 */
	ASIA_KUWAIT("Asia/Kuwait", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Asia/Macao</b> timezone.
	 */
	ASIA_MACAO("Asia/Macao", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Macau</b> timezone.
	 */
	ASIA_MACAU("Asia/Macau", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Magadan</b> timezone.
	 */
	ASIA_MAGADAN("Asia/Magadan", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Asia/Makassar</b> timezone.
	 */
	ASIA_MAKASSAR("Asia/Makassar", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Manila</b> timezone.
	 */
	ASIA_MANILA("Asia/Manila", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Muscat</b> timezone.
	 */
	ASIA_MUSCAT("Asia/Muscat", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Asia/Nicosia</b> timezone.
	 */
	ASIA_NICOSIA("Asia/Nicosia", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Novokuznetsk</b> timezone.
	 */
	ASIA_NOVOKUZNETSK("Asia/Novokuznetsk", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Novosibirsk</b> timezone.
	 */
	ASIA_NOVOSIBIRSK("Asia/Novosibirsk", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Omsk</b> timezone.
	 */
	ASIA_OMSK("Asia/Omsk", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Oral</b> timezone.
	 */
	ASIA_ORAL("Asia/Oral", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Phnom_Penh</b> timezone.
	 */
	ASIA_PHNOM_PENH("Asia/Phnom_Penh", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Pontianak</b> timezone.
	 */
	ASIA_PONTIANAK("Asia/Pontianak", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Pyongyang</b> timezone.
	 */
	ASIA_PYONGYANG("Asia/Pyongyang", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Qatar</b> timezone.
	 */
	ASIA_QATAR("Asia/Qatar", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Asia/Qyzylorda</b> timezone.
	 */
	ASIA_QYZYLORDA("Asia/Qyzylorda", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Rangoon</b> timezone.
	 */
	ASIA_RANGOON("Asia/Rangoon", UTCOffsetConstants.UTC_PLUS_06_30),

	/**
	 * International key, to use for localization, for <b>Asia/Riyadh</b> timezone.
	 */
	ASIA_RIYADH("Asia/Riyadh", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Asia/Saigon</b> timezone.
	 */
	ASIA_SAIGON("Asia/Saigon", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Sakhalin</b> timezone.
	 */
	ASIA_SAKHALIN("Asia/Sakhalin", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Asia/Samarkand</b> timezone.
	 */
	ASIA_SAMARKAND("Asia/Samarkand", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Seoul</b> timezone.
	 */
	ASIA_SEOUL("Asia/Seoul", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Shanghai</b> timezone.
	 */
	ASIA_SHANGHAI("Asia/Shanghai", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Singapore</b> timezone.
	 */
	ASIA_SINGAPORE("Asia/Singapore", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Taipei</b> timezone.
	 */
	ASIA_TAIPEI("Asia/Taipei", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Tashkent</b> timezone.
	 */
	ASIA_TASHKENT("Asia/Tashkent", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Tbilisi</b> timezone.
	 */
	ASIA_TBILISI("Asia/Tbilisi", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Asia/Tehran</b> timezone.
	 */
	ASIA_TEHRAN("Asia/Tehran", UTCOffsetConstants.UTC_PLUS_03_30),

	/**
	 * International key, to use for localization, for <b>Asia/Tel_Aviv</b> timezone.
	 */
	ASIA_TEL_AVIV("Asia/Tel_Aviv", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Asia/Thimbu</b> timezone.
	 */
	ASIA_THIMBU("Asia/Thimbu", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Thimphu</b> timezone.
	 */
	ASIA_THIMPHU("Asia/Thimphu", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Asia/Tokyo</b> timezone.
	 */
	ASIA_TOKYO("Asia/Tokyo", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ujung_Pandang</b> timezone.
	 */
	ASIA_UJUNG_PANDANG("Asia/Ujung_Pandang", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ulaanbaatar</b> timezone.
	 */
	ASIA_ULAANBAATAR("Asia/Ulaanbaatar", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ulan_Bator</b> timezone.
	 */
	ASIA_ULAN_BATOR("Asia/Ulan_Bator", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Urumqi</b> timezone.
	 */
	ASIA_URUMQI("Asia/Urumqi", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Asia/Ust-Nera</b> timezone.
	 */
	ASIA_UST_NERA("Asia/Ust-Nera", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Asia/Vientiane</b> timezone.
	 */
	ASIA_VIENTIANE("Asia/Vientiane", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Asia/Vladivostok</b> timezone.
	 */
	ASIA_VLADIVOSTOK("Asia/Vladivostok", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Asia/Yakutsk</b> timezone.
	 */
	ASIA_YAKUTSK("Asia/Yakutsk", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Asia/Yekaterinburg</b> timezone.
	 */
	ASIA_YEKATERINBURG("Asia/Yekaterinburg", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Asia/Yerevan</b> timezone.
	 */
	ASIA_YEREVAN("Asia/Yerevan", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Azores</b> timezone.
	 */
	ATLANTIC_AZORES("Atlantic/Azores", UTCOffsetConstants.UTC_MINUS_01_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Bermuda</b> timezone.
	 */
	ATLANTIC_BERMUDA("Atlantic/Bermuda", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Canary</b> timezone.
	 */
	ATLANTIC_CANARY("Atlantic/Canary", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Cape_Verde</b> timezone.
	 */
	ATLANTIC_CAPE_VERDE("Atlantic/Cape_Verde", UTCOffsetConstants.UTC_MINUS_01_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Faeroe</b> timezone.
	 */
	ATLANTIC_FAEROE("Atlantic/Faeroe", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Faroe</b> timezone.
	 */
	ATLANTIC_FAROE("Atlantic/Faroe", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Jan_Mayen</b> timezone.
	 */
	ATLANTIC_JAN_MAYEN("Atlantic/Jan_Mayen", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Madeira</b> timezone.
	 */
	ATLANTIC_MADEIRA("Atlantic/Madeira", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Reykjavik</b> timezone.
	 */
	ATLANTIC_REYKJAVIK("Atlantic/Reykjavik", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/South_Georgia</b> timezone.
	 */
	ATLANTIC_SOUTH_GEORGIA("Atlantic/South_Georgia", UTCOffsetConstants.UTC_MINUS_02_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/St_Helena</b> timezone.
	 */
	ATLANTIC_ST_HELENA("Atlantic/St_Helena", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Atlantic/Stanley</b> timezone.
	 */
	ATLANTIC_STANLEY("Atlantic/Stanley", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>Australia/ACT</b> timezone.
	 */
	AUSTRALIA_ACT("Australia/ACT", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Adelaide</b> timezone.
	 */
	AUSTRALIA_ADELAIDE("Australia/Adelaide", UTCOffsetConstants.UTC_PLUS_09_30),

	/**
	 * International key, to use for localization, for <b>Australia/Brisbane</b> timezone.
	 */
	AUSTRALIA_BRISBANE("Australia/Brisbane", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Broken_Hill</b> timezone.
	 */
	AUSTRALIA_BROKEN_HILL("Australia/Broken_Hill", UTCOffsetConstants.UTC_PLUS_09_30),

	/**
	 * International key, to use for localization, for <b>Australia/Canberra</b> timezone.
	 */
	AUSTRALIA_CANBERRA("Australia/Canberra", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Currie</b> timezone.
	 */
	AUSTRALIA_CURRIE("Australia/Currie", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Darwin</b> timezone.
	 */
	AUSTRALIA_DARWIN("Australia/Darwin", UTCOffsetConstants.UTC_PLUS_09_30),

	/**
	 * International key, to use for localization, for <b>Australia/Eucla</b> timezone.
	 */
	AUSTRALIA_EUCLA("Australia/Eucla", UTCOffsetConstants.UTC_PLUS_08_45),

	/**
	 * International key, to use for localization, for <b>Australia/Hobart</b> timezone.
	 */
	AUSTRALIA_HOBART("Australia/Hobart", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/LHI</b> timezone.
	 */
	AUSTRALIA_LHI("Australia/LHI", UTCOffsetConstants.UTC_PLUS_10_30),

	/**
	 * International key, to use for localization, for <b>Australia/Lindeman</b> timezone.
	 */
	AUSTRALIA_LINDEMAN("Australia/Lindeman", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Lord_Howe</b> timezone.
	 */
	AUSTRALIA_LORD_HOWE("Australia/Lord_Howe", UTCOffsetConstants.UTC_PLUS_10_30),

	/**
	 * International key, to use for localization, for <b>Australia/Melbourne</b> timezone.
	 */
	AUSTRALIA_MELBOURNE("Australia/Melbourne", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/NSW</b> timezone.
	 */
	AUSTRALIA_NSW("Australia/NSW", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/North</b> timezone.
	 */
	AUSTRALIA_NORTH("Australia/North", UTCOffsetConstants.UTC_PLUS_09_30),

	/**
	 * International key, to use for localization, for <b>Australia/Perth</b> timezone.
	 */
	AUSTRALIA_PERTH("Australia/Perth", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Australia/Queensland</b> timezone.
	 */
	AUSTRALIA_QUEENSLAND("Australia/Queensland", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/South</b> timezone.
	 */
	AUSTRALIA_SOUTH("Australia/South", UTCOffsetConstants.UTC_PLUS_09_30),

	/**
	 * International key, to use for localization, for <b>Australia/Sydney</b> timezone.
	 */
	AUSTRALIA_SYDNEY("Australia/Sydney", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Tasmania</b> timezone.
	 */
	AUSTRALIA_TASMANIA("Australia/Tasmania", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/Victoria</b> timezone.
	 */
	AUSTRALIA_VICTORIA("Australia/Victoria", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Australia/West</b> timezone.
	 */
	AUSTRALIA_WEST("Australia/West", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Australia/Yancowinna</b> timezone.
	 */
	AUSTRALIA_YANCOWINNA("Australia/Yancowinna", UTCOffsetConstants.UTC_PLUS_09_30),

	/**
	 * International key, to use for localization, for <b>Brazil/Acre</b> timezone.
	 */
	BRAZIL_ACRE("Brazil/Acre", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>Brazil/DeNoronha</b> timezone.
	 */
	BRAZIL_DENORONHA("Brazil/DeNoronha", UTCOffsetConstants.UTC_MINUS_02_00),

	/**
	 * International key, to use for localization, for <b>Brazil/East</b> timezone.
	 */
	BRAZIL_EAST("Brazil/East", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>Brazil/West</b> timezone.
	 */
	BRAZIL_WEST("Brazil/West", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>Canada/Atlantic</b> timezone.
	 */
	CANADA_ATLANTIC("Canada/Atlantic", UTCOffsetConstants.UTC_MINUS_04_00),

	/**
	 * International key, to use for localization, for <b>Canada/Central</b> timezone.
	 */
	CANADA_CENTRAL("Canada/Central", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>Canada/East-Saskatchewan</b> timezone.
	 */
	CANADA_EAST_SASKATCHEWAN("Canada/East-Saskatchewan", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>Canada/Eastern</b> timezone.
	 */
	CANADA_EASTERN("Canada/Eastern", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>Canada/Mountain</b> timezone.
	 */
	CANADA_MOUNTAIN("Canada/Mountain", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>Canada/Newfoundland</b> timezone.
	 */
	CANADA_NEWFOUNDLAND("Canada/Newfoundland", UTCOffsetConstants.UTC_MINUS_03_30),

	/**
	 * International key, to use for localization, for <b>Canada/Pacific</b> timezone.
	 */
	CANADA_PACIFIC("Canada/Pacific", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>Canada/Saskatchewan</b> timezone.
	 */
	CANADA_SASKATCHEWAN("Canada/Saskatchewan", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>Canada/Yukon</b> timezone.
	 */
	CANADA_YUKON("Canada/Yukon", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>Chile/Continental</b> timezone.
	 */
	CHILE_CONTINENTAL("Chile/Continental", UTCOffsetConstants.UTC_MINUS_03_00),

	/**
	 * International key, to use for localization, for <b>Chile/EasterIsland</b> timezone.
	 */
	CHILE_EASTERISLAND("Chile/EasterIsland", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>Cuba</b> timezone.
	 */
	CUBA("Cuba", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>Egypt</b> timezone.
	 */
	EGYPT("Egypt", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Eire</b> timezone.
	 */
	EIRE("Eire", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Etc/GMT+0</b> timezone.
	 */
	ETC_GMT_PLUS_0("Etc/GMT+0", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Etc/GMT</b> timezone.
	 */
	ETC_GMT("Etc/GMT", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Etc/UCT</b> timezone.
	 */
	ETC_UCT("Etc/UCT", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Etc/UTC</b> timezone.
	 */
	ETC_UTC("Etc/UTC", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Etc/Universal</b> timezone.
	 */
	ETC_UNIVERSAL("Etc/Universal", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Etc/Zulu</b> timezone.
	 */
	ETC_ZULU("Etc/Zulu", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Amsterdam</b> timezone.
	 */
	EUROPE_AMSTERDAM("Europe/Amsterdam", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Andorra</b> timezone.
	 */
	EUROPE_ANDORRA("Europe/Andorra", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Athens</b> timezone.
	 */
	EUROPE_ATHENS("Europe/Athens", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Belfast</b> timezone.
	 */
	EUROPE_BELFAST("Europe/Belfast", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Belgrade</b> timezone.
	 */
	EUROPE_BELGRADE("Europe/Belgrade", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Berlin</b> timezone.
	 */
	EUROPE_BERLIN("Europe/Berlin", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Bratislava</b> timezone.
	 */
	EUROPE_BRATISLAVA("Europe/Bratislava", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Brussels</b> timezone.
	 */
	EUROPE_BRUSSELS("Europe/Brussels", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Bucharest</b> timezone.
	 */
	EUROPE_BUCHAREST("Europe/Bucharest", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Budapest</b> timezone.
	 */
	EUROPE_BUDAPEST("Europe/Budapest", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Busingen</b> timezone.
	 */
	EUROPE_BUSINGEN("Europe/Busingen", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Chisinau</b> timezone.
	 */
	EUROPE_CHISINAU("Europe/Chisinau", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Copenhagen</b> timezone.
	 */
	EUROPE_COPENHAGEN("Europe/Copenhagen", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Dublin</b> timezone.
	 */
	EUROPE_DUBLIN("Europe/Dublin", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Gibraltar</b> timezone.
	 */
	EUROPE_GIBRALTAR("Europe/Gibraltar", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Guernsey</b> timezone.
	 */
	EUROPE_GUERNSEY("Europe/Guernsey", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Helsinki</b> timezone.
	 */
	EUROPE_HELSINKI("Europe/Helsinki", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Isle_of_Man</b> timezone.
	 */
	EUROPE_ISLE_OF_MAN("Europe/Isle_of_Man", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Istanbul</b> timezone.
	 */
	EUROPE_ISTANBUL("Europe/Istanbul", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Jersey</b> timezone.
	 */
	EUROPE_JERSEY("Europe/Jersey", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Kaliningrad</b> timezone.
	 */
	EUROPE_KALININGRAD("Europe/Kaliningrad", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Kiev</b> timezone.
	 */
	EUROPE_KIEV("Europe/Kiev", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Lisbon</b> timezone.
	 */
	EUROPE_LISBON("Europe/Lisbon", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Ljubljana</b> timezone.
	 */
	EUROPE_LJUBLJANA("Europe/Ljubljana", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/London</b> timezone.
	 */
	EUROPE_LONDON("Europe/London", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Europe/Luxembourg</b> timezone.
	 */
	EUROPE_LUXEMBOURG("Europe/Luxembourg", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Madrid</b> timezone.
	 */
	EUROPE_MADRID("Europe/Madrid", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Malta</b> timezone.
	 */
	EUROPE_MALTA("Europe/Malta", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Mariehamn</b> timezone.
	 */
	EUROPE_MARIEHAMN("Europe/Mariehamn", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Minsk</b> timezone.
	 */
	EUROPE_MINSK("Europe/Minsk", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Europe/Monaco</b> timezone.
	 */
	EUROPE_MONACO("Europe/Monaco", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Moscow</b> timezone.
	 */
	EUROPE_MOSCOW("Europe/Moscow", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Europe/Nicosia</b> timezone.
	 */
	EUROPE_NICOSIA("Europe/Nicosia", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Oslo</b> timezone.
	 */
	EUROPE_OSLO("Europe/Oslo", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Paris</b> timezone.
	 */
	EUROPE_PARIS("Europe/Paris", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Podgorica</b> timezone.
	 */
	EUROPE_PODGORICA("Europe/Podgorica", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Prague</b> timezone.
	 */
	EUROPE_PRAGUE("Europe/Prague", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Riga</b> timezone.
	 */
	EUROPE_RIGA("Europe/Riga", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Rome</b> timezone.
	 */
	EUROPE_ROME("Europe/Rome", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Samara</b> timezone.
	 */
	EUROPE_SAMARA("Europe/Samara", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Europe/San_Marino</b> timezone.
	 */
	EUROPE_SAN_MARINO("Europe/San_Marino", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Sarajevo</b> timezone.
	 */
	EUROPE_SARAJEVO("Europe/Sarajevo", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Simferopol</b> timezone.
	 */
	EUROPE_SIMFEROPOL("Europe/Simferopol", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Europe/Skopje</b> timezone.
	 */
	EUROPE_SKOPJE("Europe/Skopje", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Sofia</b> timezone.
	 */
	EUROPE_SOFIA("Europe/Sofia", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Stockholm</b> timezone.
	 */
	EUROPE_STOCKHOLM("Europe/Stockholm", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Tallinn</b> timezone.
	 */
	EUROPE_TALLINN("Europe/Tallinn", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Tirane</b> timezone.
	 */
	EUROPE_TIRANE("Europe/Tirane", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Tiraspol</b> timezone.
	 */
	EUROPE_TIRASPOL("Europe/Tiraspol", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Uzhgorod</b> timezone.
	 */
	EUROPE_UZHGOROD("Europe/Uzhgorod", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Vaduz</b> timezone.
	 */
	EUROPE_VADUZ("Europe/Vaduz", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Vatican</b> timezone.
	 */
	EUROPE_VATICAN("Europe/Vatican", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Vienna</b> timezone.
	 */
	EUROPE_VIENNA("Europe/Vienna", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Vilnius</b> timezone.
	 */
	EUROPE_VILNIUS("Europe/Vilnius", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Volgograd</b> timezone.
	 */
	EUROPE_VOLGOGRAD("Europe/Volgograd", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Europe/Warsaw</b> timezone.
	 */
	EUROPE_WARSAW("Europe/Warsaw", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Zagreb</b> timezone.
	 */
	EUROPE_ZAGREB("Europe/Zagreb", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Europe/Zaporozhye</b> timezone.
	 */
	EUROPE_ZAPOROZHYE("Europe/Zaporozhye", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Europe/Zurich</b> timezone.
	 */
	EUROPE_ZURICH("Europe/Zurich", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>GB-Eire</b> timezone.
	 */
	GB_EIRE("GB-Eire", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>GB</b> timezone.
	 */
	GB("GB", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>GMT+0</b> timezone.
	 */
	GMT_PLUS_0("GMT+0", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>GMT-0</b> timezone.
	 */
	GMT_0("GMT-0", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>GMT0</b> timezone.
	 */
	GMT0("GMT0", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>GMT</b> timezone.
	 */
	GMT("GMT", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Greenwich</b> timezone.
	 */
	GREENWICH("Greenwich", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Hongkong</b> timezone.
	 */
	HONGKONG("Hongkong", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Iceland</b> timezone.
	 */
	ICELAND("Iceland", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Indian/Antananarivo</b> timezone.
	 */
	INDIAN_ANTANANARIVO("Indian/Antananarivo", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Indian/Chagos</b> timezone.
	 */
	INDIAN_CHAGOS("Indian/Chagos", UTCOffsetConstants.UTC_PLUS_06_00),

	/**
	 * International key, to use for localization, for <b>Indian/Christmas</b> timezone.
	 */
	INDIAN_CHRISTMAS("Indian/Christmas", UTCOffsetConstants.UTC_PLUS_07_00),

	/**
	 * International key, to use for localization, for <b>Indian/Cocos</b> timezone.
	 */
	INDIAN_COCOS("Indian/Cocos", UTCOffsetConstants.UTC_PLUS_06_30),

	/**
	 * International key, to use for localization, for <b>Indian/Comoro</b> timezone.
	 */
	INDIAN_COMORO("Indian/Comoro", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Indian/Kerguelen</b> timezone.
	 */
	INDIAN_KERGUELEN("Indian/Kerguelen", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Indian/Mahe</b> timezone.
	 */
	INDIAN_MAHE("Indian/Mahe", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Indian/Maldives</b> timezone.
	 */
	INDIAN_MALDIVES("Indian/Maldives", UTCOffsetConstants.UTC_PLUS_05_00),

	/**
	 * International key, to use for localization, for <b>Indian/Mauritius</b> timezone.
	 */
	INDIAN_MAURITIUS("Indian/Mauritius", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Indian/Mayotte</b> timezone.
	 */
	INDIAN_MAYOTTE("Indian/Mayotte", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Indian/Reunion</b> timezone.
	 */
	INDIAN_REUNION("Indian/Reunion", UTCOffsetConstants.UTC_PLUS_04_00),

	/**
	 * International key, to use for localization, for <b>Iran</b> timezone.
	 */
	IRAN("Iran", UTCOffsetConstants.UTC_PLUS_03_30),

	/**
	 * International key, to use for localization, for <b>Israel</b> timezone.
	 */
	ISRAEL("Israel", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Jamaica</b> timezone.
	 */
	JAMAICA("Jamaica", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>Japan</b> timezone.
	 */
	JAPAN("Japan", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Kwajalein</b> timezone.
	 */
	KWAJALEIN("Kwajalein", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Libya</b> timezone.
	 */
	LIBYA("Libya", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>Mexico/BajaNorte</b> timezone.
	 */
	MEXICO_BAJANORTE("Mexico/BajaNorte", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>Mexico/BajaSur</b> timezone.
	 */
	MEXICO_BAJASUR("Mexico/BajaSur", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>Mexico/General</b> timezone.
	 */
	MEXICO_GENERAL("Mexico/General", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>NZ-CHAT</b> timezone.
	 */
	NZ_CHAT("NZ-CHAT", UTCOffsetConstants.UTC_PLUS_12_45),

	/**
	 * International key, to use for localization, for <b>NZ</b> timezone.
	 */
	NZ("NZ", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Navajo</b> timezone.
	 */
	NAVAJO("Navajo", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>PRC</b> timezone.
	 */
	PRC("PRC", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Apia</b> timezone.
	 */
	PACIFIC_APIA("Pacific/Apia", UTCOffsetConstants.UTC_PLUS_13_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Auckland</b> timezone.
	 */
	PACIFIC_AUCKLAND("Pacific/Auckland", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Chatham</b> timezone.
	 */
	PACIFIC_CHATHAM("Pacific/Chatham", UTCOffsetConstants.UTC_PLUS_12_45),

	/**
	 * International key, to use for localization, for <b>Pacific/Chuuk</b> timezone.
	 */
	PACIFIC_CHUUK("Pacific/Chuuk", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Easter</b> timezone.
	 */
	PACIFIC_EASTER("Pacific/Easter", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Efate</b> timezone.
	 */
	PACIFIC_EFATE("Pacific/Efate", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Enderbury</b> timezone.
	 */
	PACIFIC_ENDERBURY("Pacific/Enderbury", UTCOffsetConstants.UTC_PLUS_13_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Fakaofo</b> timezone.
	 */
	PACIFIC_FAKAOFO("Pacific/Fakaofo", UTCOffsetConstants.UTC_PLUS_13_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Fiji</b> timezone.
	 */
	PACIFIC_FIJI("Pacific/Fiji", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Funafuti</b> timezone.
	 */
	PACIFIC_FUNAFUTI("Pacific/Funafuti", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Galapagos</b> timezone.
	 */
	PACIFIC_GALAPAGOS("Pacific/Galapagos", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Gambier</b> timezone.
	 */
	PACIFIC_GAMBIER("Pacific/Gambier", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Guadalcanal</b> timezone.
	 */
	PACIFIC_GUADALCANAL("Pacific/Guadalcanal", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Guam</b> timezone.
	 */
	PACIFIC_GUAM("Pacific/Guam", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Honolulu</b> timezone.
	 */
	PACIFIC_HONOLULU("Pacific/Honolulu", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Johnston</b> timezone.
	 */
	PACIFIC_JOHNSTON("Pacific/Johnston", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Kiritimati</b> timezone.
	 */
	PACIFIC_KIRITIMATI("Pacific/Kiritimati", UTCOffsetConstants.UTC_PLUS_14_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Kosrae</b> timezone.
	 */
	PACIFIC_KOSRAE("Pacific/Kosrae", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Kwajalein</b> timezone.
	 */
	PACIFIC_KWAJALEIN("Pacific/Kwajalein", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Majuro</b> timezone.
	 */
	PACIFIC_MAJURO("Pacific/Majuro", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Marquesas</b> timezone.
	 */
	PACIFIC_MARQUESAS("Pacific/Marquesas", UTCOffsetConstants.UTC_MINUS_09_30),

	/**
	 * International key, to use for localization, for <b>Pacific/Midway</b> timezone.
	 */
	PACIFIC_MIDWAY("Pacific/Midway", UTCOffsetConstants.UTC_MINUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Nauru</b> timezone.
	 */
	PACIFIC_NAURU("Pacific/Nauru", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Niue</b> timezone.
	 */
	PACIFIC_NIUE("Pacific/Niue", UTCOffsetConstants.UTC_MINUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Norfolk</b> timezone.
	 */
	PACIFIC_NORFOLK("Pacific/Norfolk", UTCOffsetConstants.UTC_PLUS_11_30),

	/**
	 * International key, to use for localization, for <b>Pacific/Noumea</b> timezone.
	 */
	PACIFIC_NOUMEA("Pacific/Noumea", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Pago_Pago</b> timezone.
	 */
	PACIFIC_PAGO_PAGO("Pacific/Pago_Pago", UTCOffsetConstants.UTC_MINUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Palau</b> timezone.
	 */
	PACIFIC_PALAU("Pacific/Palau", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Pitcairn</b> timezone.
	 */
	PACIFIC_PITCAIRN("Pacific/Pitcairn", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Pohnpei</b> timezone.
	 */
	PACIFIC_POHNPEI("Pacific/Pohnpei", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Ponape</b> timezone.
	 */
	PACIFIC_PONAPE("Pacific/Ponape", UTCOffsetConstants.UTC_PLUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Port_Moresby</b> timezone.
	 */
	PACIFIC_PORT_MORESBY("Pacific/Port_Moresby", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Rarotonga</b> timezone.
	 */
	PACIFIC_RAROTONGA("Pacific/Rarotonga", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Saipan</b> timezone.
	 */
	PACIFIC_SAIPAN("Pacific/Saipan", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Samoa</b> timezone.
	 */
	PACIFIC_SAMOA("Pacific/Samoa", UTCOffsetConstants.UTC_MINUS_11_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Tahiti</b> timezone.
	 */
	PACIFIC_TAHITI("Pacific/Tahiti", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Tarawa</b> timezone.
	 */
	PACIFIC_TARAWA("Pacific/Tarawa", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Tongatapu</b> timezone.
	 */
	PACIFIC_TONGATAPU("Pacific/Tongatapu", UTCOffsetConstants.UTC_PLUS_13_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Truk</b> timezone.
	 */
	PACIFIC_TRUK("Pacific/Truk", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Wake</b> timezone.
	 */
	PACIFIC_WAKE("Pacific/Wake", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Wallis</b> timezone.
	 */
	PACIFIC_WALLIS("Pacific/Wallis", UTCOffsetConstants.UTC_PLUS_12_00),

	/**
	 * International key, to use for localization, for <b>Pacific/Yap</b> timezone.
	 */
	PACIFIC_YAP("Pacific/Yap", UTCOffsetConstants.UTC_PLUS_10_00),

	/**
	 * International key, to use for localization, for <b>Poland</b> timezone.
	 */
	POLAND("Poland", UTCOffsetConstants.UTC_PLUS_01_00),

	/**
	 * International key, to use for localization, for <b>Portugal</b> timezone.
	 */
	PORTUGAL("Portugal", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>ROC</b> timezone.
	 */
	ROC("ROC", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>ROK</b> timezone.
	 */
	ROK("ROK", UTCOffsetConstants.UTC_PLUS_09_00),

	/**
	 * International key, to use for localization, for <b>Singapore</b> timezone.
	 */
	SINGAPORE("Singapore", UTCOffsetConstants.UTC_PLUS_08_00),

	/**
	 * International key, to use for localization, for <b>Turkey</b> timezone.
	 */
	TURKEY("Turkey", UTCOffsetConstants.UTC_PLUS_02_00),

	/**
	 * International key, to use for localization, for <b>UCT</b> timezone.
	 */
	UCT("UCT", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>US/Alaska</b> timezone.
	 */
	US_ALASKA("US/Alaska", UTCOffsetConstants.UTC_MINUS_09_00),

	/**
	 * International key, to use for localization, for <b>US/Aleutian</b> timezone.
	 */
	US_ALEUTIAN("US/Aleutian", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>US/Arizona</b> timezone.
	 */
	US_ARIZONA("US/Arizona", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>US/Central</b> timezone.
	 */
	US_CENTRAL("US/Central", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>US/East-Indiana</b> timezone.
	 */
	US_EAST_INDIANA("US/East-Indiana", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>US/Eastern</b> timezone.
	 */
	US_EASTERN("US/Eastern", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>US/Hawaii</b> timezone.
	 */
	US_HAWAII("US/Hawaii", UTCOffsetConstants.UTC_MINUS_10_00),

	/**
	 * International key, to use for localization, for <b>US/Indiana-Starke</b> timezone.
	 */
	US_INDIANA_STARKE("US/Indiana-Starke", UTCOffsetConstants.UTC_MINUS_06_00),

	/**
	 * International key, to use for localization, for <b>US/Michigan</b> timezone.
	 */
	US_MICHIGAN("US/Michigan", UTCOffsetConstants.UTC_MINUS_05_00),

	/**
	 * International key, to use for localization, for <b>US/Mountain</b> timezone.
	 */
	US_MOUNTAIN("US/Mountain", UTCOffsetConstants.UTC_MINUS_07_00),

	/**
	 * International key, to use for localization, for <b>US/Pacific</b> timezone.
	 */
	US_PACIFIC("US/Pacific", UTCOffsetConstants.UTC_MINUS_08_00),

	/**
	 * International key, to use for localization, for <b>US/Samoa</b> timezone.
	 */
	US_SAMOA("US/Samoa", UTCOffsetConstants.UTC_MINUS_11_00),

	/**
	 * International key, to use for localization, for <b>UTC</b> timezone.
	 */
	UTC("UTC", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>Universal</b> timezone.
	 */
	UNIVERSAL("Universal", UTCOffsetConstants.UTC_PLUS_00_00),

	/**
	 * International key, to use for localization, for <b>W-SU</b> timezone.
	 */
	W_SU("W-SU", UTCOffsetConstants.UTC_PLUS_03_00),

	/**
	 * International key, to use for localization, for <b>Zulu</b> timezone.
	 */
	ZULU("Zulu", UTCOffsetConstants.UTC_PLUS_00_00);

	// value for key
	private final String value;
	// UTC offset of timezone
	private final String utcOffset;

	/**
	 * Creates the object with timezone name (value) and its UTC offset.
	 * 
	 * @param value region identifier
	 * @param utcOffset UTC offset of timezone
	 */
	private TimeZone(String value, String utcOffset) {
		this.value = value;
		this.utcOffset = utcOffset;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.commons.Key#value()
	 */
	@Override
	public String value() {
		return value;
	}

	/**
	 * Returns the UTC offset of timezone.
	 * 
	 * @return the UTC offset of timezone
	 */
	public String getUTCOffset() {
		return utcOffset;
	}

}